package com.sztzjy.money_management.controller;

import cn.hutool.core.util.IdUtil;
import com.sztzjy.money_management.annotation.AnonymousAccess;
import com.sztzjy.money_management.entity.KnowledgeSummary;
import com.sztzjy.money_management.entity.StuTrainingWithBLOBs;
import com.sztzjy.money_management.mapper.KnowledgeSummaryMapper;
import com.sztzjy.money_management.mapper.StuTrainingMapper;
import com.sztzjy.money_management.util.PdfUtil;
import com.sztzjy.money_management.util.ResultEntity;
import com.sztzjy.money_management.util.file.IFileUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;


@RestController
@Api(tags = "知识概要、知识笔记相关")
@RequestMapping("api/KnowledgeNoteController")
public class KnowledgeNoteController {

    @Autowired
    KnowledgeSummaryMapper knowledgeSummaryMapper;
    @Autowired
    StuTrainingMapper trainingMapper;
    @Autowired
    private IFileUtil fileUtil;
    @Value("${file.path}")
    private String filePath;

    //知识概要新增、编辑
    @AnonymousAccess
    @ApiOperation("知识概要-新增和修改")
    @PostMapping("saveKnowledgeSummary")
    public ResultEntity<String> saveSysKnowledgeSummary(@ApiParam("ID必传") @RequestBody KnowledgeSummary knowledgeSummary) {
        if (StringUtils.isBlank(knowledgeSummary.getChapterId())) {
            return new ResultEntity<>(HttpStatus.BAD_REQUEST, "ID不能为空！");
        }
        KnowledgeSummary sysKnowledgeSummary1 = knowledgeSummaryMapper.selectByPrimaryKey(knowledgeSummary.getChapterId());

        if (sysKnowledgeSummary1 == null) { //为空 新增
            knowledgeSummaryMapper.insert(knowledgeSummary);
            return new ResultEntity<>(HttpStatus.OK, "保存成功！");
        } else { //不为空，编辑
            knowledgeSummaryMapper.updateByPrimaryKeyWithBLOBs(knowledgeSummary);
            return new ResultEntity<>(HttpStatus.OK, "修改成功！");
        }
    }

    //知识概要查询
    @AnonymousAccess
    @ApiOperation("知识概要-查询")
    @PostMapping("getSysKnowledgeSummaryByChapterId")
    public ResultEntity<KnowledgeSummary> getSysKnowledgeSummaryByChapterId(@RequestParam String chapterId) {
        KnowledgeSummary knowledgeSummary = knowledgeSummaryMapper.selectByPrimaryKey(chapterId);
        return new ResultEntity<>(knowledgeSummary);
    }

    @AnonymousAccess
    @ApiOperation("设置知识概要学习时间（分钟）")  //获取之前的学习时间 并设置完成情况
    @PostMapping("setKnowledgeSummaryMinutes")
    public ResultEntity<String> getKnowledgeNote(@RequestParam String trainingId,@ApiParam("知识概要学习时间")@RequestParam Integer minutes) {
        StuTrainingWithBLOBs stuTrainingWithBLOBs = trainingMapper.selectByPrimaryKey(trainingId);
        Integer knowledgeSummaryCompleteStatus = stuTrainingWithBLOBs.getKnowledgeSummaryCompleteStatus();
        if(knowledgeSummaryCompleteStatus==null){
            stuTrainingWithBLOBs.setKnowledgeSummaryCompleteStatus(minutes);
        }else {
            stuTrainingWithBLOBs.setKnowledgeSummaryCompleteStatus(knowledgeSummaryCompleteStatus+minutes);
        }
        trainingMapper.updateByPrimaryKeyWithBLOBs(stuTrainingWithBLOBs);
        return new ResultEntity<>(stuTrainingWithBLOBs.getKnowledgeNote());
    }


    @AnonymousAccess
    @ApiOperation("知识笔记-保存")
    @PostMapping("saveNote")
    public ResultEntity<String> saveNote(@RequestParam String knowledgeNote,@RequestParam String trainingId) {
        StuTrainingWithBLOBs stuTrainingWithBLOBs = trainingMapper.selectByPrimaryKey(trainingId);
        if (StringUtils.isNotBlank(knowledgeNote)) {
            stuTrainingWithBLOBs.setKnowledgeNote(knowledgeNote);
            trainingMapper.updateByPrimaryKeyWithBLOBs(stuTrainingWithBLOBs);
            return new ResultEntity<>(HttpStatus.OK, "保存成功！");
        } else {
            return new ResultEntity<>(HttpStatus.BAD_REQUEST, "请输入内容后保存！");
        }
    }

    @AnonymousAccess
    @ApiOperation("知识笔记-导出")
    @GetMapping("exportNote")
    public void export(HttpServletResponse response, String context) {
        try {
            String s = IdUtil.simpleUUID();
            FileOutputStream fileOutputStream = new FileOutputStream(filePath + "/pdf/" + s + ".pdf");
            fileUtil.download(response, s + ".pdf", "/pdf/" + s + ".pdf");
            PdfUtil.htmlStringToPdf(context, fileOutputStream);
        } catch (FileNotFoundException e) {
            throw new RuntimeException(e);
        }
    }


    @AnonymousAccess
    @ApiOperation("知识笔记-回显")
    @PostMapping("getKnowledgeNote")
    public ResultEntity<String> getKnowledgeNote(@RequestParam String trainingId) {
        StuTrainingWithBLOBs stuTrainingWithBLOBs = trainingMapper.selectByPrimaryKey(trainingId);
        return new ResultEntity<>(stuTrainingWithBLOBs.getKnowledgeNote());
    }




}
