package com.sztzjy.money_management.service.impl;

import cn.hutool.core.util.IdUtil;
import com.nimbusds.jose.shaded.gson.Gson;
import com.nimbusds.jose.shaded.gson.JsonSyntaxException;
import com.sztzjy.money_management.entity.*;
import com.sztzjy.money_management.entity.dto.CaseDistributionOfPropertyFamilyDto;
import com.sztzjy.money_management.entity.dto.CaseInvestmentPlanDto;
import com.sztzjy.money_management.entity.dto.CaseInvestmentPlanSelectDto;
import com.sztzjy.money_management.mapper.*;
import com.sztzjy.money_management.service.CaseService;
import com.sztzjy.money_management.util.ResultEntity;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.*;

/**
 * @Author xcj
 * @Date 2024/8/12
 */
@Service
@Slf4j
public class CaseServiceImpl implements CaseService {
    @Autowired
    private CaseInfoMapper caseInfoMapper;
    @Autowired
    private CaseCashPlanMapper caseCashPlanMapper;
    @Autowired
    private CaseLifeEducationPlanMapper caseLifeEducationPlanMapper;
    @Autowired
    private CaseStartAnUndertakingPlanMapper caseStartAnUndertakingPlanMapper;
    @Autowired
    private CaseRetirementPlanMapper caseRetirementPlanMapper;
    @Autowired
    private CaseInsurancePlanMapper caseInsurancePlanMapper;
    @Autowired
    private CaseTaxPlanMapper caseTaxPlanMapper;
    @Autowired
    private CaseDistributionOfPropertyMapper caseDistributionOfPropertyMapper;
    @Autowired
    private CaseHeritageMapper caseHeritageMapper;
    @Autowired
    private ComCaseMapper comCaseMapper;
    @Autowired
    private CaseRiskIndexMapper caseRiskIndexMapper;
    @Autowired
    private CaseFinanceLiabilityMapper caseFinanceLiabilityMapper;
    @Autowired
    private CaseIncomeAndExpensesMapper caseIncomeAndExpensesMapper;
    @Autowired
    private CaseCashFlowMapper caseCashFlowMapper;
    @Autowired
    private CaseFinancialRatiosMapper caseFinancialRatiosMapper;
    @Autowired
    private SynthesisPlanClientMapper synthesisPlanClientMapper;
    @Autowired
    private StuTrainingMapper stuTrainingMapper;
    @Autowired
    private CaseConsumptionPlanMapper caseConsumptionPlanMapper;
    @Autowired
    private CaseDistributionOfPropertyFamilyRecordsMapper caseDistributionOfPropertyFamilyRecordsMapper;
    @Autowired
    private CaseInvestmentPlanMapper investmentPlanMapper;
    @Autowired
    private CaseInvestmentPlanBankProductInfoMapper investmentPlanBankProductInfoMapper;
    @Autowired
    private CaseInvestmentPlanFundProductInfoMapper investmentPlanFundProductInfoMapper;
    @Autowired
    private CaseInvestmentPlanInsuranceProductInfoMapper investmentPlanInsuranceProductInfoMapper;
    @Autowired
    private CaseInvestmentPlanP2PProductInfoMapper investmentPlanP2PProductInfoMapper;
    @Autowired
    private CaseInvestmentPlanRealGoldProductInfoMapper investmentPlanRealGoldProductInfoMapper;
    @Autowired
    private CaseInvestmentPlanSelectMapper caseInvestmentPlanSelectMapper;
    @Autowired
    private InsuranceProMapper insuranceProMapper;

    private void insertSynthesisPlanClient(CaseInfo newCase) {
        SynthesisPlanClient synthesisPlanClient = new SynthesisPlanClient();

        // 获取当前日期
        LocalDate currentDate = LocalDate.now();

        // 定义日期格式
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyyMMdd");

        // 格式化当前日期为字符串
        String formattedDate = currentDate.format(formatter);

        SynthesisPlanClientExample example1 = new SynthesisPlanClientExample();
        example1.setOrderByClause("create_time");
        List<SynthesisPlanClient> synthesisPlanClients = synthesisPlanClientMapper.selectByExample(example1);

        String clientNumber;
        if (synthesisPlanClients == null || synthesisPlanClients.isEmpty()) {
            // 如果没有记录，创建新的编号
            clientNumber = "C" + formattedDate + "000001";
        } else {
            // 获取最新的记录
            SynthesisPlanClient latestClient = synthesisPlanClients.get(0);
            clientNumber = latestClient.getClientNumber();

            // 提取日期和编号部分
            String datePart = clientNumber.substring(1, 9); // 取出日期部分
            String numberPart = clientNumber.substring(9);  // 取出编号部分

            // 确保日期匹配
            if (datePart.equals(formattedDate)) {
                // 递增编号部分
                int sequenceNumber = Integer.parseInt(numberPart) + 1;
                // 格式化为6位数，不足部分用0填充
                String newNumberPart = String.format("%06d", sequenceNumber);
                // 生成新的客户端编号
                clientNumber = "C" + formattedDate + newNumberPart;
            } else {
                // 日期不匹配，生成随机六位数
                Random random = new Random();
                int number = 1000 + random.nextInt(999999);
                String s = String.valueOf(number);
                // 生成新的客户端编号
                clientNumber = "C" + formattedDate + s;
            }
        }
        // 设置新的客户端编号
        synthesisPlanClient.setStuClientId(IdUtil.randomUUID());
        synthesisPlanClient.setClientNumber(clientNumber);
        synthesisPlanClient.setCaseid(newCase.getCaseid());
        synthesisPlanClient.setName(newCase.getCustomerName());
        synthesisPlanClient.setAge(newCase.getAge());
        synthesisPlanClient.setIdcard(newCase.getIdCard());
        synthesisPlanClient.setManageMoneyMattersType(newCase.getManageMoneyMattersType());
        synthesisPlanClient.setSource(newCase.getSource());
        synthesisPlanClient.setCreateTime(new Date());
        synthesisPlanClient.setSubmitStatus("未提交");
        // 插入新的记录
        synthesisPlanClientMapper.insert(synthesisPlanClient);
    }


    @Override
    public ResultEntity<HttpStatus> insertComprehensivePlanCase(StuCaseDto stuCaseDto) {
        CaseInfo caseInfo = stuCaseDto.getCaseInfo();
        //新增 综合规划表 和 客户案例信息表  包含修改
        String caseId = adminOrTeaInsert("master", caseInfo);

        //为null代表上一步报错了
        if ("false".equals(caseId)) {
            return new ResultEntity<HttpStatus>(HttpStatus.BAD_REQUEST, "系统已存在该身份证，请重试！");
        }
        //财务分析现金流量表
        CaseCashFlow caseCashFlow = new CaseCashFlow();
        //ID为空新增，不为空编辑
        if (stuCaseDto.getCaseCashFlow() != null) {

            caseCashFlow = stuCaseDto.getCaseCashFlow();

            if (StringUtils.isBlank(caseCashFlow.getCaseCashFlowId())) {
                caseCashFlow.setCaseid(caseId);
                caseCashFlow.setCaseCashFlowId(IdUtil.randomUUID());
                caseCashFlowMapper.insert(caseCashFlow);
            } else {
                caseCashFlowMapper.updateByPrimaryKey(caseCashFlow);
            }
        }

        //案例现金规划表
        CaseCashPlan caseCashPlan = new CaseCashPlan();
        //ID为空新增，不为空编辑
        if (stuCaseDto.getCaseCashPlan() != null) {
            caseCashPlan = stuCaseDto.getCaseCashPlan();

            if (StringUtils.isBlank(caseCashPlan.getCaseCashPlanId())) {
                caseCashPlan.setCaseid(caseId);
                caseCashPlan.setCaseCashPlanId(IdUtil.randomUUID());
                caseCashPlanMapper.insert(caseCashPlan);
            } else {
                caseCashPlanMapper.updateByPrimaryKeyWithBLOBs(caseCashPlan);
            }
        }

        //生涯规划-消费规划表
        CaseConsumptionPlan caseConsumptionPlan = new CaseConsumptionPlan();
        if (stuCaseDto.getCaseConsumptionPlan() != null) {
            caseConsumptionPlan = stuCaseDto.getCaseConsumptionPlan();
            //ID为空新增，不为空编辑
            if (StringUtils.isBlank(caseConsumptionPlan.getCaseConsumptionPlanId())) {
                caseConsumptionPlan.setCaseId(caseId);
                caseConsumptionPlan.setCaseConsumptionPlanId(IdUtil.randomUUID());
                caseConsumptionPlanMapper.insert(caseConsumptionPlan);
            } else {
                caseConsumptionPlanMapper.updateByPrimaryKeyWithBLOBs(caseConsumptionPlan);
            }
        }

        //案例财产分配表
        CaseDistributionOfPropertyWithBLOBs caseDistributionOfProperty = new CaseDistributionOfPropertyWithBLOBs();
        if (stuCaseDto.getCaseDistributionOfProperty() != null) {
            caseDistributionOfProperty = stuCaseDto.getCaseDistributionOfProperty();
            //ID为空新增，不为空编辑
            if (StringUtils.isBlank(caseDistributionOfProperty.getCaseDistributionOfPropertyId())) {
                caseDistributionOfProperty.setCaseid(caseId);
                caseDistributionOfProperty.setCaseDistributionOfPropertyId(IdUtil.randomUUID());
                caseDistributionOfPropertyMapper.insert(caseDistributionOfProperty);
            } else {
                caseDistributionOfPropertyMapper.updateByPrimaryKeyWithBLOBs(caseDistributionOfProperty);
            }
        }

        //财务分析-资产负债表
        CaseFinanceLiability caseFinanceLiability = new CaseFinanceLiability();
        if (stuCaseDto.getCaseFinanceLiability() != null) {
            caseFinanceLiability = stuCaseDto.getCaseFinanceLiability();
            //ID为空新增，不为空编辑
            if (StringUtils.isBlank(caseFinanceLiability.getCaseFinanceLiabilityId())) {
                caseFinanceLiability.setCaseId(caseId);
                caseFinanceLiability.setCaseFinanceLiabilityId(IdUtil.randomUUID());
                caseFinanceLiabilityMapper.insert(caseFinanceLiability);
            } else {
                caseFinanceLiabilityMapper.updateByPrimaryKey(caseFinanceLiability);
            }
        }

        //案例财务分析财务比率分析表
        CaseFinancialRatiosWithBLOBs caseFinancialRatios = new CaseFinancialRatiosWithBLOBs();
        if (stuCaseDto.getCaseFinancialRatios() != null) {
            caseFinancialRatios = stuCaseDto.getCaseFinancialRatios();
            //ID为空新增，不为空编辑
            if (StringUtils.isBlank(caseFinancialRatios.getCaseFinancialRatiosId())) {
                caseFinancialRatios.setCaseFinancialRatiosId(IdUtil.randomUUID());
                caseFinancialRatios.setCaseid(caseId);
                caseFinancialRatiosMapper.insert(caseFinancialRatios);
            } else {
                caseFinancialRatiosMapper.updateByPrimaryKeyWithBLOBs(caseFinancialRatios);
            }
        }

        //案例遗产传承表
        CaseHeritageWithBLOBs caseHeritage = new CaseHeritageWithBLOBs();
        if (stuCaseDto.getCaseHeritage() != null) {
            caseHeritage = stuCaseDto.getCaseHeritage();
            //ID为空新增，不为空编辑
            if (StringUtils.isBlank(caseHeritage.getCaseHeritageId())) {
                caseHeritage.setCaseHeritageId(IdUtil.randomUUID());
                caseHeritage.setCaseid(caseId);
                caseHeritageMapper.insert(caseHeritage);
            } else {
                caseHeritageMapper.updateByPrimaryKeyWithBLOBs(caseHeritage);
            }
        }

        //案例财务分析收支储蓄表
        CaseIncomeAndExpenses caseIncomeAndExpenses = new CaseIncomeAndExpenses();
        if (stuCaseDto.getCaseIncomeAndExpenses() != null) {
            caseIncomeAndExpenses = stuCaseDto.getCaseIncomeAndExpenses();
            //ID为空新增，不为空编辑
            if (StringUtils.isBlank(caseIncomeAndExpenses.getCaseIncomeAndExpensesId())) {
                caseIncomeAndExpenses.setCaseIncomeAndExpensesId(IdUtil.randomUUID());
                caseIncomeAndExpenses.setCaseid(caseId);
                caseIncomeAndExpensesMapper.insert(caseIncomeAndExpenses);
            } else {
                caseIncomeAndExpensesMapper.updateByPrimaryKey(caseIncomeAndExpenses);
            }
        }

        //投资规划案例表
        CaseInvestmentPlan caseInvestmentPlan = new CaseInvestmentPlan();
        if (stuCaseDto.getCaseInvestmentPlan() != null) {
            caseInvestmentPlan = stuCaseDto.getCaseInvestmentPlan();
            //ID为空新增，不为空编辑
            if (StringUtils.isBlank(caseInvestmentPlan.getCaseInvestmentPlanId())) {
                caseInvestmentPlan.setCaseInvestmentPlanId(IdUtil.randomUUID());
                caseInvestmentPlan.setCaseId(caseId);
                investmentPlanMapper.insert(caseInvestmentPlan);
            } else {
                investmentPlanMapper.updateByPrimaryKeyWithBLOBs(caseInvestmentPlan);
            }
        }

        //案例生涯规划保险规划表
        CaseInsurancePlan caseInsurancePlan = new CaseInsurancePlan();
        if (stuCaseDto.getCaseInsurancePlan() != null) {
            caseInsurancePlan = stuCaseDto.getCaseInsurancePlan();
            //ID为空新增，不为空编辑
            if (StringUtils.isBlank(caseInsurancePlan.getCaseInsurancePlanId())) {
                caseInsurancePlan.setCaseInsurancePlanId(IdUtil.randomUUID());
                caseInsurancePlan.setCaseid(caseId);
                caseInsurancePlanMapper.insert(caseInsurancePlan);
            } else {
                caseInsurancePlanMapper.updateByPrimaryKeyWithBLOBs(caseInsurancePlan);
            }
        }

        //案例生涯规划教育规划表
        CaseLifeEducationPlan caseLifeEducationPlan = new CaseLifeEducationPlan();
        if (stuCaseDto.getCaseLifeEducationPlan() != null) {
            caseLifeEducationPlan = stuCaseDto.getCaseLifeEducationPlan();
            //ID为空新增，不为空编辑
            if (StringUtils.isBlank(caseLifeEducationPlan.getCaseLifeEducationPlanId())) {
                caseLifeEducationPlan.setCaseLifeEducationPlanId(IdUtil.randomUUID());
                caseLifeEducationPlan.setCaseid(caseId);
                caseLifeEducationPlanMapper.insert(caseLifeEducationPlan);
            } else {
                caseLifeEducationPlanMapper.updateByPrimaryKeyWithBLOBs(caseLifeEducationPlan);
            }
        }

        //案例生涯规划退休规划表
        CaseRetirementPlan caseRetirementPlan = new CaseRetirementPlan();
        if (stuCaseDto.getCaseRetirementPlan() != null) {
            caseRetirementPlan = stuCaseDto.getCaseRetirementPlan();
            //ID为空新增，不为空编辑
            if (StringUtils.isBlank(caseRetirementPlan.getCaseRetirementPlanId())) {
                caseRetirementPlan.setCaseRetirementPlanId(IdUtil.randomUUID());
                caseRetirementPlan.setCaseid(caseId);
                caseRetirementPlanMapper.insert(caseRetirementPlan);
            } else {
                caseRetirementPlanMapper.updateByPrimaryKeyWithBLOBs(caseRetirementPlan);
            }
        }

        //风险测评-风险指标表
        CaseRiskIndex caseRiskIndex = new CaseRiskIndex();
        if (stuCaseDto.getCaseRiskIndex() != null) {
            caseRiskIndex = stuCaseDto.getCaseRiskIndex();
            //ID为空新增，不为空编辑
            if (StringUtils.isBlank(caseRiskIndex.getCaseRiskIndexId())) {
                caseRiskIndex.setCaseRiskIndexId(IdUtil.randomUUID());
                caseRiskIndex.setUpdateDate(new Date());
                caseRiskIndex.setCaseid(caseId);
                caseRiskIndexMapper.insert(caseRiskIndex);
            } else {
                caseRiskIndexMapper.updateByPrimaryKey(caseRiskIndex);
            }
        }

        //案例生涯规划创业规划表
        CaseStartAnUndertakingPlan caseStartAnUndertakingPlan = new CaseStartAnUndertakingPlan();
        if (stuCaseDto.getCaseStartAnUndertakingPlan() != null) {
            caseStartAnUndertakingPlan = stuCaseDto.getCaseStartAnUndertakingPlan();
            //ID为空新增，不为空编辑
            if (StringUtils.isBlank(caseStartAnUndertakingPlan.getCaseStartAnUndertakingPlanId())) {
                caseStartAnUndertakingPlan.setCaseStartAnUndertakingPlanId(IdUtil.randomUUID());
                caseStartAnUndertakingPlan.setCaseid(caseId);
                caseStartAnUndertakingPlanMapper.insert(caseStartAnUndertakingPlan);
            } else {
                caseStartAnUndertakingPlanMapper.updateByPrimaryKeyWithBLOBs(caseStartAnUndertakingPlan);
            }
        }

        //案例税务筹划表
        CaseTaxPlan caseTaxPlan = new CaseTaxPlan();
        if (stuCaseDto.getCaseTaxPlan() != null) {
            caseTaxPlan = stuCaseDto.getCaseTaxPlan();
            //ID为空新增，不为空编辑
            if (StringUtils.isBlank(caseTaxPlan.getCaseTaxPlanId())) {
                caseTaxPlan.setCaseTaxPlanId(IdUtil.randomUUID());
                caseTaxPlan.setCaseid(caseId);
                caseTaxPlanMapper.insert(caseTaxPlan);
            } else {
                caseTaxPlanMapper.updateByPrimaryKeyWithBLOBs(caseTaxPlan);
            }
        }

        return null;
    }

//    @Override
//    public BigDecimal getAnnualPremium(CaseInvestmentPlanInsuranceProductInfo productInfo) {
//        Integer age = productInfo.getAge(); //年龄
//        String gender = productInfo.getGender(); //性别
//        String insurancePeriod = productInfo.getInsurancePeriod(); //保险年份
//        String paymentMethod = productInfo.getPaymentMethod();//缴费方式
//        BigDecimal insuranceAmount = productInfo.getInsuranceAmount();//保险金额
//        String insuranceProId = productInfo.getInsuranceProId();
//        InsuranceProWithBLOBs insuranceProWithBLOBs = insuranceProMapper.selectByPrimaryKey(insuranceProId);
//        String name = insuranceProWithBLOBs.getName();//保险名称
//
//        if (name.equals("爱相随定期寿险")) {
//            if (paymentMethod.equals("趸交")) {
//                if (insurancePeriod.equals("10年")) {
//                    if (insuranceAmount.compareTo(BigDecimal.valueOf(100000)) == 0) {  //10万
//                        if (gender.equals("男")) {
//
//                        }
//                        if (gender.equals("女")) {
//
//                        }
//                    }
//                    if (insuranceAmount.compareTo(BigDecimal.valueOf(200000)) == 0) {  //20万
//                        if (gender.equals("男")) {
//
//                        }
//                        if (gender.equals("女")) {
//
//                        }
//                    }
//                    if (insuranceAmount.compareTo(BigDecimal.valueOf(300000)) == 0) {  //30万
//                        if (gender.equals("男")) {
//
//                        }
//                        if (gender.equals("女")) {
//
//                        }
//                    }
//                    if (insuranceAmount.compareTo(BigDecimal.valueOf(400000)) == 0) {  //40万
//                        if (gender.equals("男")) {
//
//                        }
//                        if (gender.equals("女")) {
//
//                        }
//                    }
//                    if (insuranceAmount.compareTo(BigDecimal.valueOf(500000)) == 0) {  //50万
//                        if (gender.equals("男")) {
//
//                        }
//                        if (gender.equals("女")) {
//
//                        }
//                    }
//                }
//                if (insurancePeriod.equals("20年")) {
//                    if (gender.equals("男")) {
//
//                    }
//                    if (gender.equals("女")) {
//
//                    }
//                }
//                if (insurancePeriod.equals("30年")) {
//                    if (gender.equals("男")) {
//
//                    }
//                    if (gender.equals("女")) {
//
//                    }
//                }
//            }
//            if (paymentMethod.equals("5年交")) {
//                if (insuranceAmount.compareTo(BigDecimal.valueOf(100000)) == 0) {  //10万
//                    if (gender.equals("男")) {
//
//                    }
//                    if (gender.equals("女")) {
//
//                    }
//                }
//                if (insuranceAmount.compareTo(BigDecimal.valueOf(200000)) == 0) {  //20万
//                    if (gender.equals("男")) {
//
//                    }
//                    if (gender.equals("女")) {
//
//                    }
//                }
//                if (insuranceAmount.compareTo(BigDecimal.valueOf(300000)) == 0) {  //30万
//                    if (gender.equals("男")) {
//
//                    }
//                    if (gender.equals("女")) {
//
//                    }
//                }
//            }
//            if (paymentMethod.equals("10年交")) {
//                if (insurancePeriod.equals("20年")) {
//                    if (gender.equals("男")) {
//
//                    }
//                    if (gender.equals("女")) {
//
//                    }
//                }
//                if (insurancePeriod.equals("30年")) {
//                    if (gender.equals("男")) {
//
//                    }
//                    if (gender.equals("女")) {
//
//                    }
//                }
//            }
//            if (paymentMethod.equals("20年交")) {
//                if (insurancePeriod.equals("30年")) {
//                    if (gender.equals("男")) {
//
//                    }
//                    if (gender.equals("女")) {
//
//                    }
//                }
//            }
//        }
//
//        return null;
//    }


    @Override
    public ResultEntity<HttpStatus> insertCase(String caseInfo, String json, String operator, String type) {
        Gson gson = new Gson();
        CaseInfo newCase = new CaseInfo();
        try {
            if (StringUtils.isNotBlank(caseInfo)) {
                newCase = gson.fromJson(caseInfo, CaseInfo.class);
            }
        } catch (JsonSyntaxException e) {
            e.printStackTrace();
            return new ResultEntity<>(HttpStatus.INTERNAL_SERVER_ERROR, "服务器错误，请联系管理员");
        }
        if (newCase != null) {
            adminOrTeaInsert(operator, newCase);
        }
        //判断是哪种考核点 增加相关表
        return addCorrelationTable(type, json, gson, operator);
    }

    private String adminOrTeaInsert(String operator, CaseInfo newCase) {
        //老师或者管理员才操作 新增或编辑案例时
        if (operator.equals("master")) {
            CaseInfoExample example = new CaseInfoExample();
            example.createCriteria().andIdCardEqualTo(newCase.getIdCard());
            List<CaseInfo> list = caseInfoMapper.selectByExampleWithBLOBs(example);

            String manageMoneyMattersType = newCase.getManageMoneyMattersType();

            //单独处理财务分析相关表的类型
            String type = getString(newCase, manageMoneyMattersType);

            //新增
            if (StringUtils.isBlank(newCase.getCaseid())) {
                if (list != null && !list.isEmpty()) { //身份证号码不允许重复
                    return "false";
                }
                //前端没传主键ID为新增
                newCase.setCaseid(IdUtil.randomUUID());
                newCase.setAddTime(new Date());
                caseInfoMapper.insert(newCase);
                //综合规划需要额外新增两张表
                if (newCase.getModel().equals("综合规划")) {
                    ComCase comCase = new ComCase();
                    comCase.setCaseid(newCase.getCaseid());
                    comCase.setComCaseId(IdUtil.randomUUID());
                    comCase.setManageMoneyMattersType(type);
                    comCaseMapper.insert(comCase);
                    insertSynthesisPlanClient(newCase);
                }
                return newCase.getCaseid();
            } else {
                //修改案例信息表
                CaseInfo caseInfo = caseInfoMapper.selectByPrimaryKey(newCase.getCaseid());
                String idCard = caseInfo.getIdCard(); //老的身份证号码

                if (!idCard.equals(newCase.getIdCard())) { //身份证号码改变了，需要判断新的是否存在
                    if (list != null && !list.isEmpty()) { //身份证号码不允许重复
                        return "false";
                    }
                }
//                //传了相同的身份证，系统判定是编辑，但是没传CaseId，直接return
//                if (StringUtils.isBlank(newCase.getCaseid())) {
//                    return "false";
//                }
                caseInfoMapper.updateByPrimaryKeySelective(newCase);

                //修改实训类型
                if (newCase.getModel().equals("综合规划")) {
                    ComCaseExample example1 = new ComCaseExample();
                    example1.createCriteria().andCaseidEqualTo(newCase.getCaseid());
                    List<ComCase> comCases = comCaseMapper.selectByExample(example1);
                    ComCase comCase = comCases.get(0);
                    comCase.setManageMoneyMattersType(type);
                    comCaseMapper.updateByPrimaryKeySelective(comCase);

                    //同时修改综合综合规划客户表
                    SynthesisPlanClientExample synthesisPlanClientExample = new SynthesisPlanClientExample();
                    synthesisPlanClientExample.createCriteria().andCaseidEqualTo(newCase.getCaseid());
                    List<SynthesisPlanClient> synthesisPlanClientList = synthesisPlanClientMapper.selectByExample(synthesisPlanClientExample);
                    if (!synthesisPlanClientList.isEmpty()) {
                        SynthesisPlanClient synthesisPlanClient = synthesisPlanClientList.get(0);
                        synthesisPlanClient.setName(newCase.getCustomerName());
                        synthesisPlanClient.setIdcard(newCase.getIdCard());
                        synthesisPlanClient.setManageMoneyMattersType(type);
                        synthesisPlanClient.setAge(newCase.getAge());
                        synthesisPlanClientMapper.updateByPrimaryKeySelective(synthesisPlanClient);
                    }
                }
                return newCase.getCaseid();
            }
        }
        return null;
    }


    //单独处理财务分析相关表的类型
    private String getString(CaseInfo newCase, String manageMoneyMattersType) {
        String[] split = manageMoneyMattersType.split(",");
        StringBuilder type = new StringBuilder();
        for (String s : split) {
            if (s.equals("财务分析")) {
                s = "财务分析-收支储蓄表,财务分析-资产负债表,财务分析-现金流量表,财务分析-财务比例分析";
            }
            type.append(s).append(",");
        }
        type = new StringBuilder(type.toString().replaceAll(",$", ""));
        newCase.setManageMoneyMattersType(type.toString());
        return type.toString();
    }


    //判断综合规划客户表是否存在,取status字段用于判断学生编辑综合规划使用
    private ResultEntity<HttpStatus> getHttpStatusResultEntity(String caseid, String userId) {
        //提交过答案则直接返回
        SynthesisPlanClientExample synthesisPlanClientExample = new SynthesisPlanClientExample();
        synthesisPlanClientExample.createCriteria().andCaseidEqualTo(caseid).andUseridEqualTo(userId);
        List<SynthesisPlanClient> synthesisPlanClientList = synthesisPlanClientMapper.selectByExample(synthesisPlanClientExample);

        //为空说明新增时创建客户规划对象失败了
        if (synthesisPlanClientList == null || synthesisPlanClientList.isEmpty()) {
            return new ResultEntity<>(HttpStatus.INTERNAL_SERVER_ERROR, "系统错误，请联系管理员！");
        }

        SynthesisPlanClient synthesisPlanClient = synthesisPlanClientList.get(0);
        if (synthesisPlanClient.getSubmitStatus() != null && !synthesisPlanClient.getSubmitStatus().equals("未提交")) {
            return new ResultEntity<>(HttpStatus.BAD_REQUEST, "提交后无法编辑！");
        }
        return null;
    }

    //添加或编辑相关类型表
    public ResultEntity<HttpStatus> addCorrelationTable(String type, String json, Gson gson, String operator) {
        try {
            if (StringUtils.isNotBlank(json)) {
                if (type.equals("风险测评-风险指标")) {
                    CaseRiskIndex caseRiskIndex = gson.fromJson(json, CaseRiskIndex.class);

                    //主键id为空则新增 否则编辑
                    if (StringUtils.isBlank(caseRiskIndex.getCaseRiskIndexId())) {
                        caseRiskIndex.setCaseRiskIndexId(IdUtil.randomUUID());
                        caseRiskIndex.setUpdateDate(new Date());
                        caseRiskIndexMapper.insert(caseRiskIndex);
                        return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                    }

                    //学生提交编辑
                    if (operator.equals("stu")) {
                        String userId = caseRiskIndex.getUserid();

                        ResultEntity<HttpStatus> result = getHttpStatusResultEntity(caseRiskIndex.getCaseid(), userId);
                        if (result != null) return result;
                    }
                    //老师和学生编辑都走这里
                    caseRiskIndexMapper.updateByPrimaryKeySelective(caseRiskIndex);
                    return new ResultEntity<>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("财务分析-资产负债表")) {
                    CaseFinanceLiability caseFinanceLiability = gson.fromJson(json, CaseFinanceLiability.class);

                    //主键id为空则新增 否则编辑
                    if (StringUtils.isBlank(caseFinanceLiability.getCaseFinanceLiabilityId())) {
                        caseFinanceLiability.setCaseFinanceLiabilityId(IdUtil.randomUUID());
                        caseFinanceLiabilityMapper.insert(caseFinanceLiability);
                        return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                    }
                    //学生提交编辑
                    if (operator.equals("stu")) {
                        String userId = caseFinanceLiability.getUserId();

                        ResultEntity<HttpStatus> result = getHttpStatusResultEntity(caseFinanceLiability.getCaseId(), userId);
                        if (result != null) return result;
                    }
                    //老师和学生编辑都走这里
                    caseFinanceLiabilityMapper.updateByPrimaryKeySelective(caseFinanceLiability);
                    return new ResultEntity<>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("财务分析-收支储蓄表")) {
                    CaseIncomeAndExpenses caseIncomeAndExpenses = gson.fromJson(json, CaseIncomeAndExpenses.class);

                    //主键id为空则新增 否则编辑
                    if (StringUtils.isBlank(caseIncomeAndExpenses.getCaseIncomeAndExpensesId())) {
                        caseIncomeAndExpenses.setCaseIncomeAndExpensesId(IdUtil.randomUUID());
                        caseIncomeAndExpensesMapper.insert(caseIncomeAndExpenses);
                        return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                    }

                    //学生提交编辑
                    if (operator.equals("stu")) {
                        String userId = caseIncomeAndExpenses.getUserId();

                        ResultEntity<HttpStatus> result = getHttpStatusResultEntity(caseIncomeAndExpenses.getCaseid(), userId);
                        if (result != null) return result;
                    }
                    //老师和学生编辑都走这里
                    caseIncomeAndExpensesMapper.updateByPrimaryKeySelective(caseIncomeAndExpenses);
                    return new ResultEntity<>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("财务分析-现金流量表")) {
                    CaseCashFlow caseCashFlow = gson.fromJson(json, CaseCashFlow.class);

                    if (StringUtils.isBlank(caseCashFlow.getCaseCashFlowId())) {
                        caseCashFlow.setCaseCashFlowId(IdUtil.randomUUID());
                        caseCashFlowMapper.insert(caseCashFlow);
                        return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                    }
                    //学生提交编辑
                    if (operator.equals("stu")) {
                        String userId = caseCashFlow.getUserId();
                        ResultEntity<HttpStatus> result = getHttpStatusResultEntity(caseCashFlow.getCaseid(), userId);
                        if (result != null) return result;
                    }
                    //老师和学生编辑都走这里
                    caseCashFlowMapper.updateByPrimaryKeySelective(caseCashFlow);
                    return new ResultEntity<>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("财务分析-财务比例分析")) {
                    CaseFinancialRatiosWithBLOBs caseFinancialRatios = gson.fromJson(json, CaseFinancialRatiosWithBLOBs.class);
                    if (StringUtils.isBlank(caseFinancialRatios.getCaseFinancialRatiosId())) {
                        caseFinancialRatios.setCaseFinancialRatiosId(IdUtil.randomUUID());
                        caseFinancialRatiosMapper.insert(caseFinancialRatios);
                        return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                    }
                    //学生提交编辑
                    if (operator.equals("stu")) {
                        String userId = caseFinancialRatios.getUserId();
                        ResultEntity<HttpStatus> result = getHttpStatusResultEntity(caseFinancialRatios.getCaseid(), userId);
                        if (result != null) return result;
                    }
                    //老师和学生编辑都走这里
                    caseFinancialRatiosMapper.updateByPrimaryKeySelective(caseFinancialRatios);
                    return new ResultEntity<>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("现金规划")) {
                    CaseCashPlan caseCashPlan = gson.fromJson(json, CaseCashPlan.class);

                    if (StringUtils.isBlank(caseCashPlan.getCaseCashPlanId())) {
                        caseCashPlan.setCaseCashPlanId(IdUtil.randomUUID());
                        caseCashPlanMapper.insert(caseCashPlan);
                        return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                    }
                    //学生提交编辑
                    if (operator.equals("stu")) {
                        String userId = caseCashPlan.getUserId();
                        ResultEntity<HttpStatus> result = getHttpStatusResultEntity(caseCashPlan.getCaseid(), userId);
                        if (result != null) return result;
                    }
                    //老师和学生编辑都走这里
                    caseCashPlanMapper.updateByPrimaryKeySelective(caseCashPlan);
                    return new ResultEntity<>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("生涯规划-教育规划")) {
                    CaseLifeEducationPlan caseLifeEducationPlan = gson.fromJson(json, CaseLifeEducationPlan.class);
                    if (StringUtils.isBlank(caseLifeEducationPlan.getCaseLifeEducationPlanId())) {
                        caseLifeEducationPlan.setCaseLifeEducationPlanId(IdUtil.randomUUID());
                        caseLifeEducationPlanMapper.insert(caseLifeEducationPlan);
                        return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                    }
                    //学生提交编辑
                    if (operator.equals("stu")) {
                        String userId = caseLifeEducationPlan.getUserId();
                        ResultEntity<HttpStatus> result = getHttpStatusResultEntity(caseLifeEducationPlan.getCaseid(), userId);
                        if (result != null) return result;
                    }
                    //老师和学生编辑都走这里
                    caseLifeEducationPlanMapper.updateByPrimaryKeySelective(caseLifeEducationPlan);
                    return new ResultEntity<>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("生涯规划-消费规划")) {
                    CaseConsumptionPlan caseConsumptionPlan = gson.fromJson(json, CaseConsumptionPlan.class);
                    if (StringUtils.isBlank(caseConsumptionPlan.getCaseConsumptionPlanId())) {
                        caseConsumptionPlan.setCaseConsumptionPlanId(IdUtil.randomUUID());
                        caseConsumptionPlanMapper.insert(caseConsumptionPlan);
                        return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                    }
                    //学生提交编辑
                    if (operator.equals("stu")) {
                        String userId = caseConsumptionPlan.getUserId();
                        ResultEntity<HttpStatus> result = getHttpStatusResultEntity(caseConsumptionPlan.getCaseId(), userId);
                        if (result != null) return result;
                    }
                    //老师和学生编辑都走这里
                    caseConsumptionPlanMapper.updateByPrimaryKeySelective(caseConsumptionPlan);
                    return new ResultEntity<>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("生涯规划-创业规划")) {
                    CaseStartAnUndertakingPlan caseStartAnUndertakingPlan = gson.fromJson(json, CaseStartAnUndertakingPlan.class);
                    if (StringUtils.isBlank(caseStartAnUndertakingPlan.getCaseStartAnUndertakingPlanId())) {
                        caseStartAnUndertakingPlan.setCaseStartAnUndertakingPlanId(IdUtil.randomUUID());
                        caseStartAnUndertakingPlanMapper.insert(caseStartAnUndertakingPlan);
                        return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                    }
                    //学生提交编辑
                    if (operator.equals("stu")) {
                        String userId = caseStartAnUndertakingPlan.getUserId();
                        ResultEntity<HttpStatus> result = getHttpStatusResultEntity(caseStartAnUndertakingPlan.getCaseid(), userId);
                        if (result != null) return result;
                    }
                    //老师和学生编辑都走这里
                    caseStartAnUndertakingPlanMapper.updateByPrimaryKeySelective(caseStartAnUndertakingPlan);
                    return new ResultEntity<>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("生涯规划-退休规划")) {
                    CaseRetirementPlan caseRetirementPlan = gson.fromJson(json, CaseRetirementPlan.class);
                    if (StringUtils.isBlank(caseRetirementPlan.getCaseRetirementPlanId())) {
                        caseRetirementPlan.setCaseRetirementPlanId(IdUtil.randomUUID());
                        caseRetirementPlanMapper.insert(caseRetirementPlan);
                        return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                    }
                    //学生提交编辑
                    if (operator.equals("stu")) {
                        String userId = caseRetirementPlan.getUserId();
                        ResultEntity<HttpStatus> result = getHttpStatusResultEntity(caseRetirementPlan.getCaseid(), userId);
                        if (result != null) return result;
                    }
                    //老师和学生编辑都走这里
                    caseRetirementPlanMapper.updateByPrimaryKeySelective(caseRetirementPlan);
                    return new ResultEntity<>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("生涯规划-保险规划")) {
                    CaseInsurancePlan caseInsurancePlan = gson.fromJson(json, CaseInsurancePlan.class);
                    if (StringUtils.isBlank(caseInsurancePlan.getCaseInsurancePlanId())) {
                        caseInsurancePlan.setCaseInsurancePlanId(IdUtil.randomUUID());
                        caseInsurancePlanMapper.insert(caseInsurancePlan);
                        return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                    }
                    //学生提交编辑
                    if (operator.equals("stu")) {
                        String userId = caseInsurancePlan.getUserId();
                        ResultEntity<HttpStatus> result = getHttpStatusResultEntity(caseInsurancePlan.getCaseid(), userId);
                        if (result != null) return result;
                    }
                    //老师和学生编辑都走这里
                    caseInsurancePlanMapper.updateByPrimaryKeySelective(caseInsurancePlan);
                    return new ResultEntity<>(HttpStatus.OK, "编辑成功！");
                }

                //投资规划表比较多，单独写接口
                if (type.equals("税务筹划")) {
                    CaseTaxPlan caseTaxPlan = gson.fromJson(json, CaseTaxPlan.class);
                    if (StringUtils.isBlank(caseTaxPlan.getCaseTaxPlanId())) {
                        caseTaxPlan.setCaseTaxPlanId(IdUtil.randomUUID());
                        caseTaxPlanMapper.insert(caseTaxPlan);
                        return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                    }
                    //学生提交编辑
                    if (operator.equals("stu")) {
                        String userId = caseTaxPlan.getUserId();
                        ResultEntity<HttpStatus> result = getHttpStatusResultEntity(caseTaxPlan.getCaseid(), userId);
                        if (result != null) return result;
                    }
                    //老师和学生编辑都走这里
                    caseTaxPlanMapper.updateByPrimaryKeySelective(caseTaxPlan);
                    return new ResultEntity<>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("财产分配")) {
                    CaseDistributionOfPropertyFamilyDto dto = gson.fromJson(json, CaseDistributionOfPropertyFamilyDto.class);
                    CaseDistributionOfPropertyWithBLOBs caseDistributionOfPropertyWithBLOBs = new CaseDistributionOfPropertyWithBLOBs();
                    BeanUtils.copyProperties(dto, caseDistributionOfPropertyWithBLOBs);
                    //id为空 新增
                    if (StringUtils.isBlank(dto.getCaseDistributionOfPropertyId())) {
                        dto.setCaseDistributionOfPropertyId(IdUtil.randomUUID());
                        caseDistributionOfPropertyWithBLOBs.setCaseDistributionOfPropertyId(IdUtil.randomUUID());
                        caseDistributionOfPropertyMapper.insert(caseDistributionOfPropertyWithBLOBs);
                    }
                    //需要多存一张记录表,多条数据
                    if (operator.equals("stu")) {
                        List<CaseDistributionOfPropertyFamilyRecords> recordsList = dto.getCaseDistributionOfPropertyFamilyRecordsList();
                        List<CaseDistributionOfPropertyFamilyRecords> addList = new ArrayList<>();
                        if (!recordsList.isEmpty()) {
                            for (CaseDistributionOfPropertyFamilyRecords caseDistributionOfPropertyFamilyRecords : recordsList) {
                                if (StringUtils.isBlank(caseDistributionOfPropertyFamilyRecords.getCaseDistributionOfPropertyFamilyRecordsId())) {
                                    caseDistributionOfPropertyFamilyRecords.setCaseDistributionOfPropertyFamilyRecordsId(IdUtil.randomUUID());
                                    caseDistributionOfPropertyFamilyRecords.setCaseDistributionOfPropertyId(caseDistributionOfPropertyWithBLOBs.getCaseDistributionOfPropertyId());
                                    caseDistributionOfPropertyFamilyRecords.setCreateTime(new Date());
                                    addList.add(caseDistributionOfPropertyFamilyRecords);
                                }
                            }
                        }
                        if (!addList.isEmpty()) {
                            caseDistributionOfPropertyFamilyRecordsMapper.batchInsert(addList);
                            return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                        }
                    }
                    //学生提交编辑
                    if (operator.equals("stu")) {
                        String userId = dto.getUserId();
                        ResultEntity<HttpStatus> result = getHttpStatusResultEntity(dto.getCaseid(), userId);
                        if (result != null) return result;
                    }

                    //老师和学生编辑都走这里
                    caseDistributionOfPropertyMapper.updateByPrimaryKeySelective(caseDistributionOfPropertyWithBLOBs);

                    List<CaseDistributionOfPropertyFamilyRecords> recordsList = dto.getCaseDistributionOfPropertyFamilyRecordsList();
                    if (recordsList != null && !recordsList.isEmpty()) {
                        for (CaseDistributionOfPropertyFamilyRecords caseDistributionOfPropertyFamilyRecords : recordsList) {
                            //先删掉老数据
                            CaseDistributionOfPropertyFamilyRecordsExample example = new CaseDistributionOfPropertyFamilyRecordsExample();
                            example.createCriteria().andCaseidEqualTo(caseDistributionOfPropertyFamilyRecords.getCaseid()).andUserIdEqualTo(caseDistributionOfPropertyFamilyRecords.getUserId())
                                    .andCaseDistributionOfPropertyIdEqualTo(caseDistributionOfPropertyFamilyRecords.getCaseDistributionOfPropertyId());
                            List<CaseDistributionOfPropertyFamilyRecords> list = caseDistributionOfPropertyFamilyRecordsMapper.selectByExample(example);
                            if (!list.isEmpty()) {
                                caseDistributionOfPropertyFamilyRecordsMapper.deleteByPrimaryKey(list.get(0).getCaseDistributionOfPropertyFamilyRecordsId());
                            }
                            caseDistributionOfPropertyFamilyRecordsMapper.insert(caseDistributionOfPropertyFamilyRecords);
                        }
                    }
                    return new ResultEntity<>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("财产传承")) {
                    CaseHeritageWithBLOBs caseHeritageWithBLOBs = gson.fromJson(json, CaseHeritageWithBLOBs.class);
                    if (StringUtils.isBlank(caseHeritageWithBLOBs.getCaseHeritageId())) {
                        caseHeritageWithBLOBs.setCaseHeritageId(IdUtil.randomUUID());
                        caseHeritageMapper.insert(caseHeritageWithBLOBs);
                        return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                    }
                    //学生提交编辑
                    if (operator.equals("stu")) {
                        String userId = caseHeritageWithBLOBs.getUserId();
                        ResultEntity<HttpStatus> result = getHttpStatusResultEntity(caseHeritageWithBLOBs.getCaseid(), userId);
                        if (result != null) return result;
                    }
                    //老师和学生编辑都走这里
                    caseHeritageMapper.updateByPrimaryKeySelective(caseHeritageWithBLOBs);
                    return new ResultEntity<>(HttpStatus.OK, "编辑成功！");
                }
            }
        } catch (
                JsonSyntaxException e) {
            e.printStackTrace();
            return new ResultEntity<>(HttpStatus.INTERNAL_SERVER_ERROR, "服务器错误，请联系管理员");
        }
        return null;
    }

    @Override
    public ResultEntity<HttpStatus> insertOrUpdateInvestmentPlan(CaseInvestmentPlanDto caseInvestmentPlanDto) {
        CaseInvestmentPlan investmentPlan = caseInvestmentPlanDto.getInvestmentPlan();

        //提交功能 主表必定不为空，把老数据查出来删掉
        CaseInvestmentPlanExample example = new CaseInvestmentPlanExample();
        example.createCriteria().andCaseIdEqualTo(investmentPlan.getCaseId()).andUserIdEqualTo(investmentPlan.getUserId()).andIsAnswerEqualTo("学生答案");
        List<CaseInvestmentPlan> caseInvestmentPlans = investmentPlanMapper.selectByExampleWithBLOBs(example);

        //删除老数据
        if (caseInvestmentPlans != null && !caseInvestmentPlans.isEmpty()) {
            CaseInvestmentPlan caseInvestmentPlan = caseInvestmentPlans.get(0);

            CaseInvestmentPlanSelectExample planSelectExample = new CaseInvestmentPlanSelectExample();
            planSelectExample.createCriteria().andCaseInvestmentPlanIdEqualTo(caseInvestmentPlan.getCaseInvestmentPlanId());
            List<CaseInvestmentPlanSelect> investmentPlanSelectsDataList = caseInvestmentPlanSelectMapper.selectByExampleWithBLOBs(planSelectExample);
            if (investmentPlanSelectsDataList != null && !investmentPlanSelectsDataList.isEmpty()) {
                CaseInvestmentPlanSelect investmentPlanSelectsData = investmentPlanSelectsDataList.get(0);
                String productSelectId = investmentPlanSelectsData.getProductSelectId();
                caseInvestmentPlanSelectMapper.deleteByPrimaryKey(productSelectId);
                caseInvestmentPlanSelectMapper.deleteByPrimaryKey(productSelectId);
                investmentPlanFundProductInfoMapper.deleteByPrimaryKey(productSelectId);
                investmentPlanBankProductInfoMapper.deleteByPrimaryKey(productSelectId);
                investmentPlanInsuranceProductInfoMapper.deleteByPrimaryKey(productSelectId);
                investmentPlanP2PProductInfoMapper.deleteByPrimaryKey(productSelectId);
                investmentPlanRealGoldProductInfoMapper.deleteByPrimaryKey(productSelectId);
            }
            investmentPlanMapper.deleteByPrimaryKey(caseInvestmentPlan.getCaseInvestmentPlanId());
        }

        //新增主表
        String newCaseInvestmentPlanId = IdUtil.randomUUID();
        investmentPlan.setCaseInvestmentPlanId(newCaseInvestmentPlanId);
        investmentPlanMapper.insert(investmentPlan);


        //投资规划-产品选择表和其余五张表是一对多关系   //下面都为新增操作
        if (caseInvestmentPlanDto.getCaseInvestmentPlanSelectDtos() != null
                && !caseInvestmentPlanDto.getCaseInvestmentPlanSelectDtos().isEmpty()) {
            List<CaseInvestmentPlanSelectDto> investmentPlanSelects = caseInvestmentPlanDto.getCaseInvestmentPlanSelectDtos();

            for (CaseInvestmentPlanSelectDto investmentPlanSelect : investmentPlanSelects) {

                CaseInvestmentPlanSelect caseInvestmentPlanSelect = investmentPlanSelect.getCaseInvestmentPlanSelect(); //产品选择表
                String selectId = IdUtil.randomUUID();

                if (caseInvestmentPlanSelect != null) {
                    caseInvestmentPlanSelect.setProductSelectId(selectId);
                    caseInvestmentPlanSelect.setCaseInvestmentPlanId(newCaseInvestmentPlanId);
                    caseInvestmentPlanSelectMapper.insert(caseInvestmentPlanSelect);
                }

                //投资规划-基金产品信息表
                if (investmentPlanSelect.getInvestmentPlanFundProductInfos() != null
                        && !investmentPlanSelect.getInvestmentPlanFundProductInfos().isEmpty()) {
                    List<CaseInvestmentPlanFundProductInfo> investmentPlanFundProductInfos = investmentPlanSelect.getInvestmentPlanFundProductInfos();

                    for (CaseInvestmentPlanFundProductInfo investmentPlanFundProductInfo : investmentPlanFundProductInfos) {
                        if (StringUtils.isBlank(investmentPlanFundProductInfo.getFundProductinfoId())) {
                            investmentPlanFundProductInfo.setFundProductinfoId(IdUtil.randomUUID());
                            investmentPlanFundProductInfo.setProductSelectId(selectId);
                            investmentPlanFundProductInfo.setAddTime(new Date());
                            investmentPlanFundProductInfoMapper.insert(investmentPlanFundProductInfo);
                        }
                    }
                }
                //投资规划-银行储蓄信息表
                if (investmentPlanSelect.getInvestmentPlanBankProductInfos() != null
                        && !investmentPlanSelect.getInvestmentPlanBankProductInfos().isEmpty()) {
                    List<CaseInvestmentPlanBankProductInfo> investmentPlanBankProductInfos = investmentPlanSelect.getInvestmentPlanBankProductInfos(); //投资规划-银行储蓄信息表
                    for (CaseInvestmentPlanBankProductInfo investmentPlanBankProductInfo : investmentPlanBankProductInfos) {
                        //id为空则新增
                        if (StringUtils.isBlank(investmentPlanBankProductInfo.getBankProductinfoId())) {
                            investmentPlanBankProductInfo.setBankProductinfoId(IdUtil.randomUUID());
                            investmentPlanBankProductInfo.setProductSelectId(selectId);
                            investmentPlanBankProductInfo.setAddTime(new Date());
                            investmentPlanBankProductInfoMapper.insert(investmentPlanBankProductInfo);
                        }
                    }
                }
                //投资规划-保险产品信息表
                if (investmentPlanSelect.getInvestmentPlanInsuranceProductInfos() != null
                        && !investmentPlanSelect.getInvestmentPlanInsuranceProductInfos().isEmpty()) {
                    List<CaseInvestmentPlanInsuranceProductInfo> investmentPlanInsuranceProductInfos = investmentPlanSelect.getInvestmentPlanInsuranceProductInfos();//投资规划-保险产品信息表

                    for (CaseInvestmentPlanInsuranceProductInfo investmentPlanInsuranceProductInfo : investmentPlanInsuranceProductInfos) {
                        //id为空则新增
                        if (StringUtils.isBlank(investmentPlanInsuranceProductInfo.getInsuranceProductinfoId())) {
                            investmentPlanInsuranceProductInfo.setInsuranceProductinfoId(IdUtil.randomUUID());
                            investmentPlanInsuranceProductInfo.setProductSelectId(selectId);
                            investmentPlanInsuranceProductInfo.setAddTime(new Date());
                            investmentPlanInsuranceProductInfoMapper.insert(investmentPlanInsuranceProductInfo);
                        }
                    }
                }
                //投资规划-P2P产品信息表
                if (investmentPlanSelect.getInvestmentPlanP2PProductInfos() != null
                        && !investmentPlanSelect.getInvestmentPlanP2PProductInfos().isEmpty()) {
                    List<CaseInvestmentPlanP2PProductInfo> investmentPlanP2PProductInfos = investmentPlanSelect.getInvestmentPlanP2PProductInfos();//投资规划-P2P产品信息表
                    for (CaseInvestmentPlanP2PProductInfo investmentPlanP2PProductInfo : investmentPlanP2PProductInfos) {
                        //id为空则新增
                        if (StringUtils.isBlank(investmentPlanP2PProductInfo.getP2pProductinfoId())) {
                            investmentPlanP2PProductInfo.setP2pProductinfoId(IdUtil.randomUUID());
                            investmentPlanP2PProductInfo.setProductSelectId(selectId);
                            investmentPlanP2PProductInfo.setAddTime(new Date());
                            investmentPlanP2PProductInfoMapper.insert(investmentPlanP2PProductInfo);
                        }
                    }
                }
                //投资规划-实物黄金信息表
                if (investmentPlanSelect.getInvestmentPlanRealGoldProductInfos() != null
                        && !investmentPlanSelect.getInvestmentPlanRealGoldProductInfos().isEmpty()) {
                    List<CaseInvestmentPlanRealGoldProductInfo> investmentPlanRealGoldProductInfos = investmentPlanSelect.getInvestmentPlanRealGoldProductInfos();//投资规划-实物黄金信息表

                    for (CaseInvestmentPlanRealGoldProductInfo investmentPlanRealGoldProductInfo : investmentPlanRealGoldProductInfos) {
                        //id为空则新增
                        if (StringUtils.isBlank(investmentPlanRealGoldProductInfo.getRealGoldProductId())) {
                            investmentPlanRealGoldProductInfo.setRealGoldProductinfoId(IdUtil.randomUUID());
                            investmentPlanRealGoldProductInfo.setProductSelectId(selectId);
                            investmentPlanRealGoldProductInfo.setAddTime(new Date());
                            investmentPlanRealGoldProductInfoMapper.insert(investmentPlanRealGoldProductInfo);
                        }
                    }
                }
            }
        }
        return new ResultEntity<HttpStatus>(HttpStatus.OK, "操作成功");
    }

//        CaseInfo newCase = new CaseInfo();
//        if (caseInvestmentPlanDto.getCaseInfo() != null) {
//            newCase = caseInvestmentPlanDto.getCaseInfo();
//        }
//        //新增或修改案例信息表
//        if (newCase != null) {
//            adminOrTeaInsert("master", newCase);
//        }
//        //老师和管理员新增/修改  只操作主表后返回
//        ResultEntity<HttpStatus> flag = teaOrAdminUpdateOrInsertInvestmentPlan(caseInvestmentPlanDto);
//        if (StringUtils.isBlank(caseInvestmentPlanDto.getUserId())) {
//            return flag;
//        }
//
//        try {
//            //学生操作多张表之后 最后返回
//            if (StringUtils.isNotBlank(caseInvestmentPlanDto.getUserId())) {
//                //判断是否提交过
//                ResultEntity<HttpStatus> result = getHttpStatusResultEntity(caseInvestmentPlanDto.getCaseId(), caseInvestmentPlanDto.getUserId());
//                if (result != null) return result;
//
//                CaseInvestmentPlan investmentPlan = caseInvestmentPlanDto.getInvestmentPlan();
//
//                //投资规划-产品选择表和其余五张表是一对多关系
//                if (caseInvestmentPlanDto.getCaseInvestmentPlanSelectDtos() != null
//                        && !caseInvestmentPlanDto.getCaseInvestmentPlanSelectDtos().isEmpty()) {
//                    List<CaseInvestmentPlanSelectDto> investmentPlanSelects = caseInvestmentPlanDto.getCaseInvestmentPlanSelectDtos();
//
//                    for (CaseInvestmentPlanSelectDto investmentPlanSelect : investmentPlanSelects) {
//
//                        CaseInvestmentPlanSelect caseInvestmentPlanSelect = investmentPlanSelect.getCaseInvestmentPlanSelect(); //产品选择表
//                        String selectId = IdUtil.randomUUID();
//                        //操作产品选择表
//                        if (caseInvestmentPlanSelect != null && StringUtils.isBlank(caseInvestmentPlanSelect.getProductSelectId())) {
//                            caseInvestmentPlanSelect.setProductSelectId(selectId);
//                            caseInvestmentPlanSelect.setCaseInvestmentPlanId(investmentPlan.getCaseInvestmentPlanId());
//                            caseInvestmentPlanSelectMapper.insert(caseInvestmentPlanSelect);
//                        } else {
//                            caseInvestmentPlanSelectMapper.updateByPrimaryKeySelective(caseInvestmentPlanSelect);
//                        }
//
//                        //投资规划-基金产品信息表
//                        if (investmentPlanSelect.getInvestmentPlanFundProductInfos() != null
//                                && !investmentPlanSelect.getInvestmentPlanFundProductInfos().isEmpty()) {
//                            List<CaseInvestmentPlanFundProductInfo> investmentPlanFundProductInfos = investmentPlanSelect.getInvestmentPlanFundProductInfos();
//                            for (CaseInvestmentPlanFundProductInfo investmentPlanFundProductInfo : investmentPlanFundProductInfos) {
//                                //id为空则新增
//                                if (StringUtils.isBlank(investmentPlanFundProductInfo.getFundProductinfoId())) {
//                                    investmentPlanFundProductInfo.setFundProductinfoId(IdUtil.randomUUID());
//                                    investmentPlanFundProductInfo.setProductSelectId(selectId);
//                                    investmentPlanFundProductInfo.setAddTime(new Date());
//                                    investmentPlanFundProductInfoMapper.insert(investmentPlanFundProductInfo);
//                                } else {
//                                    investmentPlanFundProductInfoMapper.updateByPrimaryKeySelective(investmentPlanFundProductInfo);
//                                }
//                            }
//                        }
//                        //投资规划-银行储蓄信息表
//                        if (investmentPlanSelect.getInvestmentPlanBankProductInfos() != null
//                                && !investmentPlanSelect.getInvestmentPlanBankProductInfos().isEmpty()) {
//                            List<CaseInvestmentPlanBankProductInfo> investmentPlanBankProductInfos = investmentPlanSelect.getInvestmentPlanBankProductInfos(); //投资规划-银行储蓄信息表
//                            for (CaseInvestmentPlanBankProductInfo investmentPlanBankProductInfo : investmentPlanBankProductInfos) {
//                                //id为空则新增
//                                if (StringUtils.isBlank(investmentPlanBankProductInfo.getBankProductinfoId())) {
//                                    investmentPlanBankProductInfo.setBankProductinfoId(IdUtil.randomUUID());
//                                    investmentPlanBankProductInfo.setProductSelectId(selectId);
//                                    investmentPlanBankProductInfo.setAddTime(new Date());
//                                    investmentPlanBankProductInfoMapper.insert(investmentPlanBankProductInfo);
//                                } else {
//                                    investmentPlanBankProductInfoMapper.updateByPrimaryKeySelective(investmentPlanBankProductInfo);
//                                }
//                            }
//                        }
//                        //投资规划-保险产品信息表
//                        if (investmentPlanSelect.getInvestmentPlanInsuranceProductInfos() != null
//                                && !investmentPlanSelect.getInvestmentPlanInsuranceProductInfos().isEmpty()) {
//                            List<CaseInvestmentPlanInsuranceProductInfo> investmentPlanInsuranceProductInfos = investmentPlanSelect.getInvestmentPlanInsuranceProductInfos();//投资规划-保险产品信息表
//
//                            for (CaseInvestmentPlanInsuranceProductInfo investmentPlanInsuranceProductInfo : investmentPlanInsuranceProductInfos) {
//                                //id为空则新增
//                                if (StringUtils.isBlank(investmentPlanInsuranceProductInfo.getInsuranceProductinfoId())) {
//                                    investmentPlanInsuranceProductInfo.setInsuranceProductinfoId(IdUtil.randomUUID());
//                                    investmentPlanInsuranceProductInfo.setProductSelectId(selectId);
//                                    investmentPlanInsuranceProductInfo.setAddTime(new Date());
//                                    investmentPlanInsuranceProductInfoMapper.insert(investmentPlanInsuranceProductInfo);
//                                } else {
//                                    investmentPlanInsuranceProductInfoMapper.updateByPrimaryKeySelective(investmentPlanInsuranceProductInfo);
//                                }
//                            }
//                        }
//                        //投资规划-P2P产品信息表
//                        if (investmentPlanSelect.getInvestmentPlanP2PProductInfos() != null
//                                && !investmentPlanSelect.getInvestmentPlanP2PProductInfos().isEmpty()) {
//                            List<CaseInvestmentPlanP2PProductInfo> investmentPlanP2PProductInfos = investmentPlanSelect.getInvestmentPlanP2PProductInfos();//投资规划-P2P产品信息表
//                            for (CaseInvestmentPlanP2PProductInfo investmentPlanP2PProductInfo : investmentPlanP2PProductInfos) {
//                                //id为空则新增
//                                if (StringUtils.isBlank(investmentPlanP2PProductInfo.getP2pProductinfoId())) {
//                                    investmentPlanP2PProductInfo.setP2pProductinfoId(IdUtil.randomUUID());
//                                    investmentPlanP2PProductInfo.setProductSelectId(selectId);
//                                    investmentPlanP2PProductInfo.setAddTime(new Date());
//                                    investmentPlanP2PProductInfoMapper.insert(investmentPlanP2PProductInfo);
//                                } else {
//                                    investmentPlanP2PProductInfoMapper.updateByPrimaryKeySelective(investmentPlanP2PProductInfo);
//                                }
//                            }
//                        }
//                        //投资规划-实物黄金信息表
//                        if (investmentPlanSelect.getInvestmentPlanRealGoldProductInfos() != null
//                                && !investmentPlanSelect.getInvestmentPlanRealGoldProductInfos().isEmpty()) {
//                            List<CaseInvestmentPlanRealGoldProductInfo> investmentPlanRealGoldProductInfos = investmentPlanSelect.getInvestmentPlanRealGoldProductInfos();//投资规划-实物黄金信息表
//
//                            for (CaseInvestmentPlanRealGoldProductInfo investmentPlanRealGoldProductInfo : investmentPlanRealGoldProductInfos) {
//                                //id为空则新增
//                                if (StringUtils.isBlank(investmentPlanRealGoldProductInfo.getRealGoldProductId())) {
//                                    investmentPlanRealGoldProductInfo.setRealGoldProductId(IdUtil.randomUUID());
//                                    investmentPlanRealGoldProductInfo.setProductSelectId(selectId);
//                                    investmentPlanRealGoldProductInfo.setAddTime(new Date());
//                                    investmentPlanRealGoldProductInfoMapper.insert(investmentPlanRealGoldProductInfo);
//                                } else {
//                                    investmentPlanRealGoldProductInfoMapper.updateByPrimaryKeySelective(investmentPlanRealGoldProductInfo);
//                                }
//                            }
//                        }
//                    }
//                }
//            }
//        } catch (
//                Exception e) {
//            e.printStackTrace();
//            return new ResultEntity<HttpStatus>(HttpStatus.INTERNAL_SERVER_ERROR, "系统错误，请联系管理员！");
//        }
//        return new ResultEntity<HttpStatus>(HttpStatus.OK, "操作成功！");
//    }

//
//    private ResultEntity<HttpStatus> teaOrAdminUpdateOrInsertInvestmentPlan(CaseInvestmentPlanDto
//                                                                                    caseInvestmentPlanDto) {
//        if (caseInvestmentPlanDto.getInvestmentPlan() == null) {
//            return null;
//        }
//        CaseInvestmentPlan investmentPlan = caseInvestmentPlanDto.getInvestmentPlan();
//
//        if (StringUtils.isBlank(investmentPlan.getCaseInvestmentPlanId())) { //主键为空为新增
//            investmentPlan.setCaseInvestmentPlanId(IdUtil.randomUUID());
//            investmentPlanMapper.insert(investmentPlan);
//            return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
//        } else {
//            investmentPlanMapper.updateByPrimaryKeySelective(investmentPlan);
//            return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
//        }
//    }

    //直接拿这个对象对比会有问题，BigDecimal类型 管理员端存答案到数据库后保留了两位小数 .00 所以只能先存数据库再查出来，或者两边都切换成double类型比较
    @Override  //重新实训 先把数据库的数据替换成本次数据，再设置实训表中的数据，没分数则加上，有则不改。2、算分只算老师端设置的考核点
    public void commitTraining(String json, String type, String trainingId) {
        StuTrainingWithBLOBs stuTrainingWithBLOBs = stuTrainingMapper.selectByPrimaryKey(trainingId);

        int wrongCount = 0;
        Gson gson = new Gson();
        //判断是哪种考核点 增加相关表
        try {
            if (StringUtils.isNotBlank(json)) {
                if (type.equals("风险测评-风险指标")) {
                    CaseRiskIndex stuRiskIndex = gson.fromJson(json, CaseRiskIndex.class);

                    //先查一次数据库，提交过就把原来的记录删掉再重新新增，但是不更新training表的得分
                    CaseRiskIndexExample caseRiskIndexExample = new CaseRiskIndexExample();
                    caseRiskIndexExample.createCriteria().andIsAnswerEqualTo("学生答案").andUseridEqualTo(stuRiskIndex.getUserid()).andCaseidEqualTo(stuRiskIndex.getCaseid());
                    List<CaseRiskIndex> caseRiskIndices = caseRiskIndexMapper.selectByExample(caseRiskIndexExample);

                    //新增对象
                    stuRiskIndex.setCaseRiskIndexId(IdUtil.randomUUID());
                    stuRiskIndex.setUpdateDate(new Date());
                    caseRiskIndexMapper.insert(stuRiskIndex);

                    //有数据，只删除原数据 修改学生答案 不算分
                    if (!caseRiskIndices.isEmpty()) {
                        for (CaseRiskIndex caseRiskIndex : caseRiskIndices) {
                            caseRiskIndexMapper.deleteByPrimaryKey(caseRiskIndex.getCaseRiskIndexId());
                        }
                    } else { //没数据 算分
                        List<CaseRiskIndex> newCaseRiskIndices = caseRiskIndexMapper.selectByExample(caseRiskIndexExample);
                        CaseRiskIndex caseRiskIndex = newCaseRiskIndices.get(0);

                        //比较正确答案
                        wrongCount = getRiskIndexWrongCount(wrongCount, caseRiskIndex);
                        setCount(stuTrainingWithBLOBs, wrongCount);
                    }
                }

                if (type.equals("财务分析-资产负债表")) {
                    CaseFinanceLiability stuData = gson.fromJson(json, CaseFinanceLiability.class);

                    CaseFinanceLiabilityExample caseRiskIndexExample = new CaseFinanceLiabilityExample();
                    caseRiskIndexExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseIdEqualTo(stuData.getCaseId());
                    List<CaseFinanceLiability> caseFinanceLiabilities = caseFinanceLiabilityMapper.selectByExample(caseRiskIndexExample);

                    stuData.setCaseFinanceLiabilityId(IdUtil.randomUUID());
                    caseFinanceLiabilityMapper.insert(stuData);

                    if (!caseFinanceLiabilities.isEmpty()) {
                        for (CaseFinanceLiability caseFinanceLiability : caseFinanceLiabilities) {
                            caseFinanceLiabilityMapper.deleteByPrimaryKey(caseFinanceLiability.getCaseFinanceLiabilityId());
                        }
                    } else { //没数据 算分
                        //比较正确答案
                        List<CaseFinanceLiability> newCaseFinanceLiabilities = caseFinanceLiabilityMapper.selectByExample(caseRiskIndexExample);
                        CaseFinanceLiability caseFinanceLiability = newCaseFinanceLiabilities.get(0);
                        wrongCount = getCaseFinanceLiabilityWrongCount(wrongCount, caseFinanceLiability);
                        setCount(stuTrainingWithBLOBs, wrongCount);
                    }

                }

                if (type.equals("财务分析-收支储蓄表")) {
                    CaseIncomeAndExpenses stuData = gson.fromJson(json, CaseIncomeAndExpenses.class);

                    CaseIncomeAndExpensesExample caseIncomeAndExpensesExample = new CaseIncomeAndExpensesExample();
                    caseIncomeAndExpensesExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseIncomeAndExpenses> caseFinanceLiabilities = caseIncomeAndExpensesMapper.selectByExample(caseIncomeAndExpensesExample);

                    stuData.setCaseIncomeAndExpensesId(IdUtil.randomUUID());
                    caseIncomeAndExpensesMapper.insert(stuData);

                    if (!caseFinanceLiabilities.isEmpty()) {
                        for (CaseIncomeAndExpenses caseIncomeAndExpenses : caseFinanceLiabilities) {
                            caseIncomeAndExpensesMapper.deleteByPrimaryKey(caseIncomeAndExpenses.getCaseIncomeAndExpensesId());
                        }
                    } else { //没数据 算分
                        List<CaseIncomeAndExpenses> newCaseFinanceLiabilities = caseIncomeAndExpensesMapper.selectByExample(caseIncomeAndExpensesExample);
                        CaseIncomeAndExpenses caseIncomeAndExpenses = newCaseFinanceLiabilities.get(0);
                        wrongCount = getCaseIncomeAndExpensesWrongCount(wrongCount, caseIncomeAndExpenses);
                        //比较正确答案
                        setCount(stuTrainingWithBLOBs, wrongCount);
                    }
                }

                if (type.equals("财务分析-现金流量表")) {
                    CaseCashFlow stuData = gson.fromJson(json, CaseCashFlow.class);

                    CaseCashFlowExample caseCashFlowExample = new CaseCashFlowExample();
                    caseCashFlowExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseCashFlow> caseCashFlows = caseCashFlowMapper.selectByExample(caseCashFlowExample);

                    stuData.setCaseCashFlowId(IdUtil.randomUUID());
                    caseCashFlowMapper.insert(stuData);

                    if (!caseCashFlows.isEmpty()) {
                        for (CaseCashFlow caseCashFlow : caseCashFlows) {
                            caseCashFlowMapper.deleteByPrimaryKey(caseCashFlow.getCaseCashFlowId());
                        }
                    } else { //没数据 算分
                        List<CaseCashFlow> newCaseCashFlows = caseCashFlowMapper.selectByExample(caseCashFlowExample);
                        CaseCashFlow caseCashFlow = newCaseCashFlows.get(0);
                        //比较正确答案
                        wrongCount = getCaseCashFlowWrongCount(wrongCount, caseCashFlow);
                        setCount(stuTrainingWithBLOBs, wrongCount);
                    }
                }

                if (type.equals("财务分析-财务比例分析")) {
                    CaseFinancialRatiosWithBLOBs stuData = gson.fromJson(json, CaseFinancialRatiosWithBLOBs.class);

                    CaseFinancialRatiosExample caseFinancialRatiosExample = new CaseFinancialRatiosExample();
                    caseFinancialRatiosExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseFinancialRatiosWithBLOBs> caseFinancialRatiosWithBLOBs = caseFinancialRatiosMapper.selectByExampleWithBLOBs(caseFinancialRatiosExample);

                    stuData.setCaseFinancialRatiosId(IdUtil.randomUUID());
                    caseFinancialRatiosMapper.insert(stuData);

                    if (!caseFinancialRatiosWithBLOBs.isEmpty()) {
                        for (CaseFinancialRatiosWithBLOBs financialRatiosWithBLOBs : caseFinancialRatiosWithBLOBs) {
                            caseFinancialRatiosMapper.deleteByPrimaryKey(financialRatiosWithBLOBs.getCaseFinancialRatiosId());
                        }
                    }
                    //老师端考核点为一个主观题，无需比较正确答案
                }

                if (type.equals("现金规划")) {
                    CaseCashPlan stuData = gson.fromJson(json, CaseCashPlan.class);

                    CaseCashPlanExample caseCashPlanExample = new CaseCashPlanExample();
                    caseCashPlanExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseCashPlan> caseCashPlans = caseCashPlanMapper.selectByExampleWithBLOBs(caseCashPlanExample);

                    stuData.setCaseCashPlanId(IdUtil.randomUUID());
                    caseCashPlanMapper.insert(stuData);

                    if (!caseCashPlans.isEmpty()) {
                        for (CaseCashPlan caseCashPlan : caseCashPlans) {
                            caseCashPlanMapper.deleteByPrimaryKey(caseCashPlan.getCaseCashPlanId());
                        }
                    } else { //没数据 算分
                        //比较正确答案
                        List<CaseCashPlan> newCaseCashPlans = caseCashPlanMapper.selectByExampleWithBLOBs(caseCashPlanExample);
                        CaseCashPlan caseCashPlan = newCaseCashPlans.get(0);
                        wrongCount = getCaseCashPlanWrongCount(wrongCount, caseCashPlan);
                        setCount(stuTrainingWithBLOBs, wrongCount);
                    }
                }

                if (type.equals("生涯规划-教育规划")) {
                    CaseLifeEducationPlan stuData = gson.fromJson(json, CaseLifeEducationPlan.class);

                    CaseLifeEducationPlanExample caseLifeEducationPlanExample = new CaseLifeEducationPlanExample();
                    caseLifeEducationPlanExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseLifeEducationPlan> caseLifeEducationPlans = caseLifeEducationPlanMapper.selectByExampleWithBLOBs(caseLifeEducationPlanExample);

                    stuData.setCaseLifeEducationPlanId(IdUtil.randomUUID());
                    caseLifeEducationPlanMapper.insert(stuData);

                    if (!caseLifeEducationPlans.isEmpty()) {
                        for (CaseLifeEducationPlan caseLifeEducationPlan : caseLifeEducationPlans) {
                            caseLifeEducationPlanMapper.deleteByPrimaryKey(caseLifeEducationPlan.getCaseLifeEducationPlanId());
                        }
                    } else { //没数据 算分
                        List<CaseLifeEducationPlan> newCaseLifeEducationPlans = caseLifeEducationPlanMapper.selectByExampleWithBLOBs(caseLifeEducationPlanExample);
                        CaseLifeEducationPlan caseLifeEducationPlan = newCaseLifeEducationPlans.get(0);
                        //比较正确答案
                        wrongCount = getCaseLifeEducationPlanWrongCount(wrongCount, caseLifeEducationPlan);
                        setCount(stuTrainingWithBLOBs, wrongCount);
                    }
                }

                if (type.equals("生涯规划-消费规划")) {
                    CaseConsumptionPlan stuData = gson.fromJson(json, CaseConsumptionPlan.class);

                    CaseConsumptionPlanExample caseConsumptionPlanExample = new CaseConsumptionPlanExample();
                    caseConsumptionPlanExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseIdEqualTo(stuData.getCaseId());
                    List<CaseConsumptionPlan> caseConsumptionPlans = caseConsumptionPlanMapper.selectByExampleWithBLOBs(caseConsumptionPlanExample); //todo 测试看下这里能不能查出来

                    stuData.setCaseConsumptionPlanId(IdUtil.randomUUID());
                    caseConsumptionPlanMapper.insert(stuData);

                    if (!caseConsumptionPlans.isEmpty()) {
                        for (CaseConsumptionPlan caseConsumptionPlan : caseConsumptionPlans) {
                            caseConsumptionPlanMapper.deleteByPrimaryKey(caseConsumptionPlan.getCaseConsumptionPlanId());
                        }
                    } else { //没数据 算分
                        //比较正确答案

                        List<CaseConsumptionPlan> newCaseConsumptionPlans = caseConsumptionPlanMapper.selectByExampleWithBLOBs(caseConsumptionPlanExample); //todo 测试看下这里能不能查出来
                        CaseConsumptionPlan caseConsumptionPlan = newCaseConsumptionPlans.get(0);
                        wrongCount = getCaseConsumptionPlanWrongCount(wrongCount, caseConsumptionPlan);
                        setCount(stuTrainingWithBLOBs, wrongCount);
                    }
                }

                if (type.equals("生涯规划-创业规划")) {
                    CaseStartAnUndertakingPlan stuData = gson.fromJson(json, CaseStartAnUndertakingPlan.class);

                    CaseStartAnUndertakingPlanExample caseStartAnUndertakingPlanExample = new CaseStartAnUndertakingPlanExample();
                    caseStartAnUndertakingPlanExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseStartAnUndertakingPlan> caseLifeEducationPlans = caseStartAnUndertakingPlanMapper.selectByExampleWithBLOBs(caseStartAnUndertakingPlanExample);

                    stuData.setCaseStartAnUndertakingPlanId(IdUtil.randomUUID());
                    caseStartAnUndertakingPlanMapper.insert(stuData);

                    if (!caseLifeEducationPlans.isEmpty()) {
                        for (CaseStartAnUndertakingPlan caseStartAnUndertakingPlan : caseLifeEducationPlans) {
                            caseStartAnUndertakingPlanMapper.deleteByPrimaryKey(caseStartAnUndertakingPlan.getCaseStartAnUndertakingPlanId());
                        }
                    } else { //没数据 算分
                        //比较正确答案
                        List<CaseStartAnUndertakingPlan> newCaseLifeEducationPlans = caseStartAnUndertakingPlanMapper.selectByExampleWithBLOBs(caseStartAnUndertakingPlanExample);
                        CaseStartAnUndertakingPlan caseStartAnUndertakingPlan = newCaseLifeEducationPlans.get(0);
                        wrongCount = getCaseStartAnUndertakingPlanWrongCount(wrongCount, caseStartAnUndertakingPlan);
                        setCount(stuTrainingWithBLOBs, wrongCount);
                    }
                }

                if (type.equals("生涯规划-退休规划")) {
                    CaseRetirementPlan stuData = gson.fromJson(json, CaseRetirementPlan.class);

                    CaseRetirementPlanExample caseRetirementPlanExample = new CaseRetirementPlanExample();
                    caseRetirementPlanExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseRetirementPlan> caseRetirementPlans = caseRetirementPlanMapper.selectByExampleWithBLOBs(caseRetirementPlanExample);

                    stuData.setCaseRetirementPlanId(IdUtil.randomUUID());
                    caseRetirementPlanMapper.insert(stuData);

                    if (!caseRetirementPlans.isEmpty()) {
                        for (CaseRetirementPlan caseRetirementPlan : caseRetirementPlans) {
                            caseRetirementPlanMapper.deleteByPrimaryKey(caseRetirementPlan.getCaseRetirementPlanId());
                        }
                    } else { //没数据 算分
                        //比较正确答案
                        List<CaseRetirementPlan> newCaseRetirementPlans = caseRetirementPlanMapper.selectByExampleWithBLOBs(caseRetirementPlanExample);
                        CaseRetirementPlan caseRetirementPlan = newCaseRetirementPlans.get(0);
                        wrongCount = getCaseRetirementPlanWrongCount(wrongCount, caseRetirementPlan);
                        setCount(stuTrainingWithBLOBs, wrongCount);
                    }
                }

                if (type.equals("生涯规划-保险规划")) {
                    CaseInsurancePlan stuData = gson.fromJson(json, CaseInsurancePlan.class);

                    CaseInsurancePlanExample caseInsurancePlanExample = new CaseInsurancePlanExample();
                    caseInsurancePlanExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseInsurancePlan> caseRetirementPlans = caseInsurancePlanMapper.selectByExampleWithBLOBs(caseInsurancePlanExample);

                    stuData.setCaseInsurancePlanId(IdUtil.randomUUID());
                    caseInsurancePlanMapper.insert(stuData);

                    if (!caseRetirementPlans.isEmpty()) {
                        for (CaseInsurancePlan caseInsurancePlan : caseRetirementPlans) {
                            caseInsurancePlanMapper.deleteByPrimaryKey(caseInsurancePlan.getCaseInsurancePlanId());
                        }
                    } else { //没数据 算分
                        List<CaseInsurancePlan> newCaseRetirementPlans = caseInsurancePlanMapper.selectByExampleWithBLOBs(caseInsurancePlanExample);
                        CaseInsurancePlan caseInsurancePlan = newCaseRetirementPlans.get(0);
                        //比较正确答案
                        wrongCount = getCaseInsurancePlanWrongCount(wrongCount, caseInsurancePlan);
                        setCount(stuTrainingWithBLOBs, wrongCount);
                    }
                }

                //先查询一次
                if (type.equals("投资规划")) {
                    CaseInvestmentPlanDto caseInvestmentPlanDto = gson.fromJson(json, CaseInvestmentPlanDto.class);

                    CaseInvestmentPlan investmentPlan = caseInvestmentPlanDto.getInvestmentPlan();

                    //提交功能 主表必定不为空，把老数据查出来删掉
                    CaseInvestmentPlanExample example = new CaseInvestmentPlanExample();
                    example.createCriteria().andCaseIdEqualTo(investmentPlan.getCaseId()).andUserIdEqualTo(investmentPlan.getUserId()).andIsAnswerEqualTo("学生答案");
                    List<CaseInvestmentPlan> caseInvestmentPlans = investmentPlanMapper.selectByExampleWithBLOBs(example);

                    //新增主表
                    String newCaseInvestmentPlanId = IdUtil.randomUUID();
                    investmentPlan.setCaseInvestmentPlanId(newCaseInvestmentPlanId);
                    investmentPlanMapper.insert(investmentPlan);

                    //删除老数据
                    if (caseInvestmentPlans != null && !caseInvestmentPlans.isEmpty()) {
                        CaseInvestmentPlan caseInvestmentPlan = caseInvestmentPlans.get(0);

                        CaseInvestmentPlanSelectExample planSelectExample = new CaseInvestmentPlanSelectExample();
                        planSelectExample.createCriteria().andCaseInvestmentPlanIdEqualTo(caseInvestmentPlan.getCaseInvestmentPlanId());
                        List<CaseInvestmentPlanSelect> investmentPlanSelectsDataList = caseInvestmentPlanSelectMapper.selectByExampleWithBLOBs(planSelectExample);
                        if (investmentPlanSelectsDataList != null && !investmentPlanSelectsDataList.isEmpty()) {
                            CaseInvestmentPlanSelect investmentPlanSelectsData = investmentPlanSelectsDataList.get(0);
                            String productSelectId = investmentPlanSelectsData.getProductSelectId();
                            caseInvestmentPlanSelectMapper.deleteByPrimaryKey(productSelectId);
                            caseInvestmentPlanSelectMapper.deleteByPrimaryKey(productSelectId);
                            investmentPlanFundProductInfoMapper.deleteByPrimaryKey(productSelectId);
                            investmentPlanBankProductInfoMapper.deleteByPrimaryKey(productSelectId);
                            investmentPlanInsuranceProductInfoMapper.deleteByPrimaryKey(productSelectId);
                            investmentPlanP2PProductInfoMapper.deleteByPrimaryKey(productSelectId);
                            investmentPlanRealGoldProductInfoMapper.deleteByPrimaryKey(productSelectId);
                        }
                        investmentPlanMapper.deleteByPrimaryKey(caseInvestmentPlan.getCaseInvestmentPlanId());
                    } else { //没数据 算分
                        List<CaseInvestmentPlan> newCaseInvestmentPlans = investmentPlanMapper.selectByExampleWithBLOBs(example);
                        CaseInvestmentPlan caseInvestmentPlan = newCaseInvestmentPlans.get(0);
                        //比较正确答案
                        wrongCount = getCaseInvestmentPlan(wrongCount, caseInvestmentPlan);
                        setCount(stuTrainingWithBLOBs, wrongCount);
                    }


                    //投资规划-产品选择表和其余五张表是一对多关系   //下面都为新增操作
                    if (caseInvestmentPlanDto.getCaseInvestmentPlanSelectDtos() != null
                            && !caseInvestmentPlanDto.getCaseInvestmentPlanSelectDtos().isEmpty()) {
                        List<CaseInvestmentPlanSelectDto> investmentPlanSelects = caseInvestmentPlanDto.getCaseInvestmentPlanSelectDtos();

                        for (CaseInvestmentPlanSelectDto investmentPlanSelect : investmentPlanSelects) {

                            CaseInvestmentPlanSelect caseInvestmentPlanSelect = investmentPlanSelect.getCaseInvestmentPlanSelect(); //产品选择表
                            String selectId = IdUtil.randomUUID();

                            if (caseInvestmentPlanSelect != null) {
                                caseInvestmentPlanSelect.setProductSelectId(selectId);
                                caseInvestmentPlanSelect.setCaseInvestmentPlanId(newCaseInvestmentPlanId);
                                caseInvestmentPlanSelectMapper.insert(caseInvestmentPlanSelect);
                            }

                            //投资规划-基金产品信息表
                            if (investmentPlanSelect.getInvestmentPlanFundProductInfos() != null
                                    && !investmentPlanSelect.getInvestmentPlanFundProductInfos().isEmpty()) {
                                List<CaseInvestmentPlanFundProductInfo> investmentPlanFundProductInfos = investmentPlanSelect.getInvestmentPlanFundProductInfos();

                                for (CaseInvestmentPlanFundProductInfo investmentPlanFundProductInfo : investmentPlanFundProductInfos) {
                                    if (StringUtils.isBlank(investmentPlanFundProductInfo.getFundProductinfoId())) {
                                        investmentPlanFundProductInfo.setFundProductinfoId(IdUtil.randomUUID());
                                        investmentPlanFundProductInfo.setProductSelectId(selectId);
                                        investmentPlanFundProductInfo.setAddTime(new Date());
                                        investmentPlanFundProductInfoMapper.insert(investmentPlanFundProductInfo);
                                    }
                                }
                            }
                            //投资规划-银行储蓄信息表
                            if (investmentPlanSelect.getInvestmentPlanBankProductInfos() != null
                                    && !investmentPlanSelect.getInvestmentPlanBankProductInfos().isEmpty()) {
                                List<CaseInvestmentPlanBankProductInfo> investmentPlanBankProductInfos = investmentPlanSelect.getInvestmentPlanBankProductInfos(); //投资规划-银行储蓄信息表
                                for (CaseInvestmentPlanBankProductInfo investmentPlanBankProductInfo : investmentPlanBankProductInfos) {
                                    //id为空则新增
                                    if (StringUtils.isBlank(investmentPlanBankProductInfo.getBankProductinfoId())) {
                                        investmentPlanBankProductInfo.setBankProductinfoId(IdUtil.randomUUID());
                                        investmentPlanBankProductInfo.setProductSelectId(selectId);
                                        investmentPlanBankProductInfo.setAddTime(new Date());
                                        investmentPlanBankProductInfoMapper.insert(investmentPlanBankProductInfo);
                                    }
                                }
                            }
                            //投资规划-保险产品信息表
                            if (investmentPlanSelect.getInvestmentPlanInsuranceProductInfos() != null
                                    && !investmentPlanSelect.getInvestmentPlanInsuranceProductInfos().isEmpty()) {
                                List<CaseInvestmentPlanInsuranceProductInfo> investmentPlanInsuranceProductInfos = investmentPlanSelect.getInvestmentPlanInsuranceProductInfos();//投资规划-保险产品信息表

                                for (CaseInvestmentPlanInsuranceProductInfo investmentPlanInsuranceProductInfo : investmentPlanInsuranceProductInfos) {
                                    //id为空则新增
                                    if (StringUtils.isBlank(investmentPlanInsuranceProductInfo.getInsuranceProductinfoId())) {
                                        investmentPlanInsuranceProductInfo.setInsuranceProductinfoId(IdUtil.randomUUID());
                                        investmentPlanInsuranceProductInfo.setProductSelectId(selectId);
                                        investmentPlanInsuranceProductInfo.setAddTime(new Date());
                                        investmentPlanInsuranceProductInfoMapper.insert(investmentPlanInsuranceProductInfo);
                                    }
                                }
                            }
                            //投资规划-P2P产品信息表
                            if (investmentPlanSelect.getInvestmentPlanP2PProductInfos() != null
                                    && !investmentPlanSelect.getInvestmentPlanP2PProductInfos().isEmpty()) {
                                List<CaseInvestmentPlanP2PProductInfo> investmentPlanP2PProductInfos = investmentPlanSelect.getInvestmentPlanP2PProductInfos();//投资规划-P2P产品信息表
                                for (CaseInvestmentPlanP2PProductInfo investmentPlanP2PProductInfo : investmentPlanP2PProductInfos) {
                                    //id为空则新增
                                    if (StringUtils.isBlank(investmentPlanP2PProductInfo.getP2pProductinfoId())) {
                                        investmentPlanP2PProductInfo.setP2pProductinfoId(IdUtil.randomUUID());
                                        investmentPlanP2PProductInfo.setProductSelectId(selectId);
                                        investmentPlanP2PProductInfo.setAddTime(new Date());
                                        investmentPlanP2PProductInfoMapper.insert(investmentPlanP2PProductInfo);
                                    }
                                }
                            }
                            //投资规划-实物黄金信息表
                            if (investmentPlanSelect.getInvestmentPlanRealGoldProductInfos() != null
                                    && !investmentPlanSelect.getInvestmentPlanRealGoldProductInfos().isEmpty()) {
                                List<CaseInvestmentPlanRealGoldProductInfo> investmentPlanRealGoldProductInfos = investmentPlanSelect.getInvestmentPlanRealGoldProductInfos();//投资规划-实物黄金信息表

                                for (CaseInvestmentPlanRealGoldProductInfo investmentPlanRealGoldProductInfo : investmentPlanRealGoldProductInfos) {
                                    //id为空则新增
                                    if (StringUtils.isBlank(investmentPlanRealGoldProductInfo.getRealGoldProductId())) {
                                        investmentPlanRealGoldProductInfo.setRealGoldProductinfoId(IdUtil.randomUUID());
                                        investmentPlanRealGoldProductInfo.setProductSelectId(selectId);
                                        investmentPlanRealGoldProductInfo.setAddTime(new Date());
                                        investmentPlanRealGoldProductInfoMapper.insert(investmentPlanRealGoldProductInfo);
                                    }
                                }
                            }
                        }
                    }
                }

                if (type.equals("税务筹划")) {
                    CaseTaxPlan stuData = gson.fromJson(json, CaseTaxPlan.class);

                    CaseTaxPlanExample caseTaxPlanExample = new CaseTaxPlanExample();
                    caseTaxPlanExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseTaxPlan> caseTaxPlans = caseTaxPlanMapper.selectByExampleWithBLOBs(caseTaxPlanExample);

                    stuData.setCaseTaxPlanId(IdUtil.randomUUID());
                    caseTaxPlanMapper.insert(stuData);

                    if (!caseTaxPlans.isEmpty()) {
                        for (CaseTaxPlan caseTaxPlan : caseTaxPlans) {
                            caseTaxPlanMapper.deleteByPrimaryKey(caseTaxPlan.getCaseTaxPlanId());
                        }
                    } else { //没数据 算分
                        //比较正确答案
                        List<CaseTaxPlan> newCaseTaxPlans = caseTaxPlanMapper.selectByExampleWithBLOBs(caseTaxPlanExample);
                        CaseTaxPlan caseTaxPlan = newCaseTaxPlans.get(0);
                        wrongCount = getCaseTaxPlanWrongCount(wrongCount, caseTaxPlan);
                        setCount(stuTrainingWithBLOBs, wrongCount);
                    }
                }

                if (type.equals("财产分配")) {
                    CaseDistributionOfPropertyFamilyDto stuData = gson.fromJson(json, CaseDistributionOfPropertyFamilyDto.class);

                    CaseDistributionOfPropertyExample caseDistributionOfPropertyExample = new CaseDistributionOfPropertyExample();
                    caseDistributionOfPropertyExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseDistributionOfPropertyWithBLOBs> caseDistributionOfPropertyWithBLOBs = caseDistributionOfPropertyMapper.selectByExampleWithBLOBs(caseDistributionOfPropertyExample);
                    if (!caseDistributionOfPropertyWithBLOBs.isEmpty()) {
                        for (CaseDistributionOfPropertyWithBLOBs distributionOfPropertyWithBLOBs : caseDistributionOfPropertyWithBLOBs) {
                            caseDistributionOfPropertyMapper.deleteByPrimaryKey(distributionOfPropertyWithBLOBs.getCaseDistributionOfPropertyId());
                        }
                    }
                    CaseDistributionOfPropertyWithBLOBs newData = new CaseDistributionOfPropertyWithBLOBs();
                    BeanUtils.copyProperties(stuData, newData);
                    String id = IdUtil.randomUUID();
                    newData.setCaseDistributionOfPropertyId(id);
                    caseDistributionOfPropertyMapper.insert(newData);

                    List<CaseDistributionOfPropertyFamilyRecords> list = new ArrayList<>();
                    if (stuData.getCaseDistributionOfPropertyFamilyRecordsList() != null && !stuData.getCaseDistributionOfPropertyFamilyRecordsList().isEmpty()) {
                        List<CaseDistributionOfPropertyFamilyRecords> caseDistributionOfPropertyFamilyRecordsList = stuData.getCaseDistributionOfPropertyFamilyRecordsList();
                        for (CaseDistributionOfPropertyFamilyRecords caseDistributionOfPropertyFamilyRecords : caseDistributionOfPropertyFamilyRecordsList) {
                            caseDistributionOfPropertyFamilyRecords.setCaseDistributionOfPropertyId(id);
                            caseDistributionOfPropertyFamilyRecords.setCaseDistributionOfPropertyFamilyRecordsId(IdUtil.randomUUID());
                            caseDistributionOfPropertyFamilyRecords.setCreateTime(new Date());
                            list.add(caseDistributionOfPropertyFamilyRecords);
                        }
                        caseDistributionOfPropertyFamilyRecordsMapper.batchInsert(list);
                    }
                    //主观题按字数算分，50一个
                    int score = getCaseDistributionOfPropertyScore(stuData);
                    setCount(stuTrainingWithBLOBs, score);
                }

                if (type.equals("财产传承")) {
                    CaseHeritageWithBLOBs stuData = gson.fromJson(json, CaseHeritageWithBLOBs.class);

                    CaseHeritageExample caseHeritageExample = new CaseHeritageExample();
                    caseHeritageExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseHeritageWithBLOBs> caseHeritageWithBLOBs = caseHeritageMapper.selectByExampleWithBLOBs(caseHeritageExample);

                    stuData.setCaseHeritageId(IdUtil.randomUUID());
                    caseHeritageMapper.insert(stuData);

                    if (!caseHeritageWithBLOBs.isEmpty()) {
                        for (CaseHeritageWithBLOBs distributionOfPropertyWithBLOBs : caseHeritageWithBLOBs) {
                            caseHeritageMapper.deleteByPrimaryKey(distributionOfPropertyWithBLOBs.getCaseHeritageId());
                        }
                    } else { //没数据 算分
                        List<CaseHeritageWithBLOBs> newCaseHeritageWithBLOBs = caseHeritageMapper.selectByExampleWithBLOBs(caseHeritageExample);
                        CaseHeritageWithBLOBs newCaseHeritage = newCaseHeritageWithBLOBs.get(0);
                        //比较正确答案
                        wrongCount = getCaseHeritageWrongCount(wrongCount, newCaseHeritage);
                        setCount(stuTrainingWithBLOBs, wrongCount);
                    }
                }
            }
        } catch (
                Exception e) {
            e.printStackTrace();
            throw new RuntimeException("实训提交失败");
        }
    }

    private int getCaseDistributionOfPropertyScore(CaseDistributionOfPropertyFamilyDto stuData) {
        int a = 0;  //主观题 50分一个 10个5分
        int b = 0;
        if (StringUtils.isNotBlank(stuData.getPlanAnalysis())) {
            String planAnalysis = stuData.getPlanAnalysis();
            // 去除空格、标点符号和数字
            String cleanedInput = planAnalysis.replaceAll("[\\s\\p{Punct}\\d]", "");
            int length = cleanedInput.length();
            // 根据长度计算分数，每10个5分
            a = Math.min(length / 10, 10) * 5;
        }
        if (StringUtils.isNotBlank(stuData.getSituationAnalysis())) {
            String situationAnalysis = stuData.getSituationAnalysis();
            String cleanedInput = situationAnalysis.replaceAll("[\\s\\p{Punct}\\d]", "");
            int length = cleanedInput.length();
            b = Math.min(length / 10, 10) * 5;
        }
        return a + b;
    }


    private void setCount(StuTrainingWithBLOBs stuTrainingWithBLOBs, int wrongCount) {
        if (stuTrainingWithBLOBs.getExpTrainingCompleteStatus() == null) {
            stuTrainingWithBLOBs.setExpTrainingCompleteStatus(wrongCount);
        } else {
            Integer expTrainingCompleteStatus = stuTrainingWithBLOBs.getExpTrainingCompleteStatus();
            expTrainingCompleteStatus += wrongCount;
            stuTrainingWithBLOBs.setExpTrainingCompleteStatus(expTrainingCompleteStatus);
        }
        stuTrainingMapper.updateByPrimaryKeySelective(stuTrainingWithBLOBs);
    }

    private int getCaseInvestmentPlan(int wrongCount, CaseInvestmentPlan stuInvestmentPlan) {
        CaseInvestmentPlanExample example = new CaseInvestmentPlanExample();
        example.createCriteria().andCaseIdEqualTo(stuInvestmentPlan.getCaseId()).andIsAnswerEqualTo("题目答案");
        List<CaseInvestmentPlan> caseInvestmentPlans = investmentPlanMapper.selectByExampleWithBLOBs(example);

        if (caseInvestmentPlans != null && !caseInvestmentPlans.isEmpty()) {
            CaseInvestmentPlan investmentPlan = caseInvestmentPlans.get(0);
            //当前客户所处家庭生命周期
            if (StringUtils.isNotBlank(investmentPlan.getLifeCycleId())) {
                if (StringUtils.isBlank(stuInvestmentPlan.getLifeCycleId()) || !stuInvestmentPlan.getLifeCycleId().equals(investmentPlan.getLifeCycleId())) {
                    wrongCount += 1;
                }
            }
        }
        return wrongCount;
    }

    private int getCaseConsumptionPlanWrongCount(int wrongCount, CaseConsumptionPlan stuData) {
        CaseConsumptionPlanExample example = new CaseConsumptionPlanExample();
        example.createCriteria().andCaseIdEqualTo(stuData.getCaseId()).andIsAnswerEqualTo("题目答案");
        List<CaseConsumptionPlan> CaseConsumptionPlans = caseConsumptionPlanMapper.selectByExampleWithBLOBs(example);

        if (CaseConsumptionPlans != null && !CaseConsumptionPlans.isEmpty()) {
            CaseConsumptionPlan rightData = CaseConsumptionPlans.get(0);
            //距离购房年限
            if (rightData.getShopHouseYear() != null) {
                if (stuData.getShopHouseYear() == null || stuData.getShopHouseYear().compareTo(rightData.getShopHouseYear()) != 0) {
                    wrongCount += 1;
                }
            }
            //购房 总金额
            if (rightData.getHouseAllMoney() != null) {
                if (stuData.getHouseAllMoney() == null
                        || stuData.getHouseAllMoney().doubleValue() != (rightData.getHouseAllMoney().doubleValue())) {
                    wrongCount += 1;
                }
            }
            //首付比例
            if (rightData.getHouseDownPaymentPercent() != null) {
                if (stuData.getHouseDownPaymentPercent() == null
                        || !stuData.getHouseDownPaymentPercent().equals(rightData.getHouseDownPaymentPercent())) {
                    wrongCount += 1;
                }
            }
            //贷款年限
            if (rightData.getHouseLoanYear() != null) {
                if (stuData.getHouseLoanYear() == null
                        || !stuData.getHouseLoanYear().equals(rightData.getHouseLoanYear())) {
                    wrongCount += 1;
                }
            }
            //贷款利率
            if (rightData.getHouseLoanRate() != null) {
                if (stuData.getHouseLoanRate() == null
                        || !stuData.getHouseLoanRate().equals(rightData.getHouseLoanRate())) {
                    wrongCount += 1;
                }
            }
            //距离购车年限
            if (rightData.getShopCarYear() != null) {
                if (stuData.getShopCarYear() == null
                        || !stuData.getShopCarYear().equals(rightData.getShopCarYear())) {
                    wrongCount += 1;
                }
            }
            //裸车价格
            if (rightData.getCarPrice() != null) {
                if (stuData.getCarPrice() == null
                        || (stuData.getCarPrice().doubleValue()) != (rightData.getCarPrice().doubleValue())) {
                    wrongCount += 1;
                }
            }
            //首付比例
            if (rightData.getCarDownPaymentPercent() != null) {
                if (stuData.getCarDownPaymentPercent() == null
                        || !stuData.getCarDownPaymentPercent().equals(rightData.getCarDownPaymentPercent())) {
                    wrongCount += 1;
                }
            }
            //贷款年限
            if (rightData.getCarLoanYear() != null) {
                if (stuData.getCarLoanYear() == null
                        || !stuData.getCarLoanYear().equals(rightData.getCarLoanYear())) {
                    wrongCount += 1;
                }
            }
            //贷款利率
            if (rightData.getCarLoanRate() != null) {
                if (stuData.getCarLoanRate() == null
                        || !stuData.getCarLoanRate().equals(rightData.getCarLoanRate())) {
                    wrongCount += 1;
                }
            }
            //上牌费用
            if (rightData.getCarRegFee() != null)
                if (stuData.getCarRegFee() == null
                        || !stuData.getCarRegFee().equals(rightData.getCarRegFee())) {
                    wrongCount += 1;
                }
            //车船使用税
            if (rightData.getVehicleAndVesselTax() != null) {
                if (rightData.getVehicleAndVesselTax() == null
                        || !stuData.getVehicleAndVesselTax().equals(rightData.getVehicleAndVesselTax())) {
                    wrongCount += 1;
                }
            }
            //商业保险
            if (rightData.getMotorVehicleCommercial() != null) {
                if (stuData.getMotorVehicleCommercial() == null
                        || !stuData.getMotorVehicleCommercial().equals(rightData.getMotorVehicleCommercial())) {
                    wrongCount += 1;
                }
            }
        }
        return wrongCount;
    }

    private int getCaseHeritageWrongCount(int wrongCount, CaseHeritageWithBLOBs stuData) {
        CaseHeritageExample example = new CaseHeritageExample();
        example.createCriteria().andCaseidEqualTo(stuData.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseHeritageWithBLOBs> caseHeritageWithBLOBs = caseHeritageMapper.selectByExampleWithBLOBs(example);
        if (caseHeritageWithBLOBs != null && !caseHeritageWithBLOBs.isEmpty()) {
            CaseHeritageWithBLOBs rightData = caseHeritageWithBLOBs.get(0);
            //现金
            if (rightData.getCash() != null) {
                if (stuData.getCash() == null
                        || !stuData.getCash().equals(rightData.getCash())) {
                    wrongCount += 1;
                }
            }
            //银行存款
            if (rightData.getDeposit() != null) {
                if (stuData.getDeposit() == null
                        || !stuData.getDeposit().equals(rightData.getDeposit())) {
                    wrongCount += 1;
                }
            }
            //人寿保单赔偿金额
            if (rightData.getLifeInsurance() != null) {
                if (stuData.getLifeInsurance() == null
                        || !stuData.getLifeInsurance().equals(rightData.getLifeInsurance())) {
                    wrongCount += 1;
                }
            }
            //其他现金账户
            if (rightData.getOtherCashAccount() != null) {
                if (stuData.getOtherCashAccount() == null
                        || !stuData.getOtherCashAccount().equals(rightData.getOtherCashAccount())) {
                    wrongCount += 1;
                }
            }
            //股票
            if (rightData.getStock() != null) {
                if (stuData.getStock() == null
                        || !stuData.getStock().equals(rightData.getStock())) {
                    wrongCount += 1;
                }
            }
            //债券
            if (rightData.getBond() != null) {
                if (stuData.getBond() == null
                        || !stuData.getBond().equals(rightData.getBond())) {
                    wrongCount += 1;
                }
            }
            //基金
            if (rightData.getFund() != null) {
                if (stuData.getFund() == null
                        || !stuData.getFund().equals(rightData.getFund())) {
                    wrongCount += 1;
                }
            }
            //其他投资收益
            if (rightData.getOtherInvestment() != null) {
                if (stuData.getOtherInvestment() == null
                        || !stuData.getOtherInvestment().equals(rightData.getOtherInvestment())) {
                    wrongCount += 1;
                }
            }
            //养老金（一次性收入现值）
            if (rightData.getPension() != null) {
                if (stuData.getPension() == null
                        || !stuData.getPension().equals(rightData.getPension())) {
                    wrongCount += 1;
                }
            }
            //配偶/遗孤年金收益（现值）
            if (rightData.getAnnuityRevenue() != null) {
                if (stuData.getAnnuityRevenue() == null
                        || !stuData.getAnnuityRevenue().equals(rightData.getAnnuityRevenue())) {
                    wrongCount += 1;
                }
            }
            //其他退休基金
            if (rightData.getOtherPension() != null) {
                if (stuData.getOtherPension() == null
                        || !stuData.getOtherPension().equals(rightData.getOtherPension())) {
                    wrongCount += 1;
                }
            }
            //房产
            if (rightData.getHouse() != null) {
                if (stuData.getHouse() == null
                        || !stuData.getHouse().equals(rightData.getHouse())) {
                    wrongCount += 1;
                }
            }
            //汽车
            if (rightData.getCar() != null) {
                if (stuData.getCar() == null
                        || !stuData.getCar().equals(rightData.getCar())) {
                    wrongCount += 1;
                }
            }
            //其他个人资产
            if (rightData.getOther() != null) {
                if (stuData.getOther() == null
                        || !stuData.getOther().equals(rightData.getOther())) {
                    wrongCount += 1;
                }
            }
            //其他资产
            if (rightData.getOtherProperty() != null) {
                if (stuData.getOtherProperty() == null
                        || !stuData.getOtherProperty().equals(rightData.getOtherProperty())) {
                    wrongCount += 1;
                }
            }
            //短期贷款
            if (rightData.getShortTermLoan() != null) {
                if (stuData.getShortTermLoan() == null
                        || !stuData.getShortTermLoan().equals(rightData.getShortTermLoan())) {
                    wrongCount += 1;
                }
            }
            //中期贷款
            if (rightData.getMediumTermLoans() != null) {
                if (stuData.getMediumTermLoans() == null
                        || !stuData.getMediumTermLoans().equals(rightData.getMediumTermLoans())) {
                    wrongCount += 1;
                }
            }
            //长期贷款
            if (rightData.getLongTermLoan() != null) {
                if (stuData.getLongTermLoan() == null
                        || !stuData.getLongTermLoan().equals(rightData.getLongTermLoan())) {
                    wrongCount += 1;
                }
            }
            //其他贷款
            if (rightData.getOtherLoan() != null) {
                if (stuData.getOtherLoan() == null
                        || !stuData.getOtherLoan().equals(rightData.getOtherLoan())) {
                    wrongCount += 1;
                }
            }
            //临终医疗费用
            if (rightData.getMedicalCosts() != null) {
                if (stuData.getMedicalCosts() == null
                        || !stuData.getMedicalCosts().equals(rightData.getMedicalCosts())) {
                    wrongCount += 1;
                }
            }
            //预期收入纳税额支出
            if (rightData.getTaxCosts() != null) {
                if (stuData.getTaxCosts() == null
                        || !stuData.getTaxCosts().equals(rightData.getTaxCosts())) {
                    wrongCount += 1;
                }
            }
            //丧葬费用
            if (rightData.getFuneralExpenses() != null) {
                if (stuData.getFuneralExpenses() == null
                        || !stuData.getFuneralExpenses().equals(rightData.getFuneralExpenses())) {
                    wrongCount += 1;
                }
            }
            //遗产处置费用
            if (rightData.getHeritageCosts() != null) {
                if (stuData.getHeritageCosts() == null
                        || !stuData.getHeritageCosts().equals(rightData.getHeritageCosts())) {
                    wrongCount += 1;
                }
            }
            //其他费用
            if (rightData.getOtherCosts() != null) {
                if (stuData.getOtherCosts() == null
                        || !stuData.getOtherCosts().equals(rightData.getOtherCosts())) {
                    wrongCount += 1;
                }
            }
            //其他负债
            if (rightData.getOtherLiabilities() != null) {
                if (stuData.getOtherLiabilities() == null
                        || !stuData.getOtherLiabilities().equals(rightData.getOtherLiabilities())) {
                    wrongCount += 1;
                }
            }
        }
        return wrongCount;
    }

    private int getCaseTaxPlanWrongCount(int wrongCount, CaseTaxPlan stuData) {
        CaseTaxPlanExample example = new CaseTaxPlanExample();
        example.createCriteria().andCaseidEqualTo(stuData.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseTaxPlan> caseTaxPlans = caseTaxPlanMapper.selectByExampleWithBLOBs(example);

        if (caseTaxPlans != null && !caseTaxPlans.isEmpty()) {
            CaseTaxPlan rightData = caseTaxPlans.get(0);
            //工资、薪金所得
            if (rightData.getSalary() != null) {
                if (stuData.getSalary() == null
                        || stuData.getSalary().compareTo(rightData.getSalary()) != 0) {
                    wrongCount += 1;
                }
            }
            //个体工商户的生产、经营所得
            if (rightData.getOperatingRevenue() != null) {
                if (stuData.getOperatingRevenue() == null
                        || stuData.getOperatingRevenue().compareTo(rightData.getOperatingRevenue()) != 0) {
                    wrongCount += 1;
                }
            }
            //对企事业单位承包、承租经营所得
            if (rightData.getEnterprisesRevenue() != null) {
                if (stuData.getEnterprisesRevenue() == null
                        || stuData.getEnterprisesRevenue().compareTo(rightData.getEnterprisesRevenue()) != 0) {
                    wrongCount += 1;
                }
            }
            //劳务报酬所得税
            if (rightData.getServiceIncome() != null) {
                if (stuData.getServiceIncome() == null
                        || stuData.getServiceIncome().compareTo(rightData.getServiceIncome()) != 0) {
                    wrongCount += 1;
                }
            }
            //稿酬所得
            if (rightData.getRemuneration() != null) {
                if (stuData.getRemuneration() == null
                        || stuData.getRemuneration().compareTo(rightData.getRemuneration()) != 0) {
                    wrongCount += 1;
                }
            }
            //特许权使用费所得
            if (rightData.getLoyalities() != null) {
                if (stuData.getLoyalities() == null
                        || stuData.getLoyalities().compareTo(rightData.getLoyalities()) != 0) {
                    wrongCount += 1;
                }
            }
            //财产转让所得
            if (rightData.getDemise() != null) {
                if (stuData.getDemise() == null
                        || stuData.getDemise().compareTo(rightData.getDemise()) != 0) {
                    wrongCount += 1;
                }
            }
            //偶然所得
            if (rightData.getIncidentalIncome() != null) {
                if (stuData.getIncidentalIncome() == null
                        || stuData.getIncidentalIncome().compareTo(rightData.getIncidentalIncome()) != 0) {
                    wrongCount += 1;
                }
            }
            //利息、红利、股利所得
            if (rightData.getInterest() != null) {
                if (stuData.getInterest() == null
                        || stuData.getInterest().compareTo(rightData.getInterest()) != 0) {
                    wrongCount += 1;
                }
            }
        }
        return wrongCount;
    }

    private int getCaseInsurancePlanWrongCount(int wrongCount, CaseInsurancePlan stuData) {
        CaseInsurancePlanExample example = new CaseInsurancePlanExample();
        example.createCriteria().andCaseidEqualTo(stuData.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseInsurancePlan> caseInsurancePlans = caseInsurancePlanMapper.selectByExampleWithBLOBs(example);
        if (caseInsurancePlans != null && !caseInsurancePlans.isEmpty()) {
            CaseInsurancePlan rightData = caseInsurancePlans.get(0);
            if (stuData.getMethodTypeId().equals("遗嘱需求法")) {
                //配偶名称
                if (rightData.getSpouseName() != null) {
                    if (stuData.getSpouseName() == null
                            || !stuData.getSpouseName().equals(rightData.getSpouseName())) {
                        wrongCount += 1;
                    }
                }
                //被保险人年龄--配偶
                if (rightData.getAgec() != null) {
                    if (stuData.getAgec() == null
                            || !stuData.getAgec().equals(rightData.getAgec())) {
                        wrongCount += 1;
                    }
                }
                //预计退休年龄-客户
                if (rightData.getRetirementAgeb() != null) {
                    if (stuData.getRetirementAgeb() == null
                            || !stuData.getRetirementAgeb().equals(rightData.getRetirementAgeb())) {
                        wrongCount += 1;
                    }
                }
                //预计退休年龄-配偶
                if (rightData.getRetirementAgec() != null) {
                    if (stuData.getRetirementAgec() == null
                            || !stuData.getRetirementAgec().equals(rightData.getRetirementAgec())) {
                        wrongCount += 1;
                    }
                }
                //投资报酬率-客户
                if (rightData.getReturnOnInvestmentb() != null) {
                    if (stuData.getReturnOnInvestmentb() == null
                            || stuData.getReturnOnInvestmentb().compareTo(rightData.getReturnOnInvestmentb()) != 0) {
                        wrongCount += 1;
                    }
                }
                //投资报酬率-配偶
                if (rightData.getReturnOnInvestmentc() != null) {
                    if (stuData.getReturnOnInvestmentc() == null
                            || stuData.getReturnOnInvestmentc().compareTo(rightData.getReturnOnInvestmentc()) != 0) {
                        wrongCount += 1;
                    }
                }
                //通货膨胀率-客户
                if (rightData.getInflationRateb() != null) {
                    if (stuData.getInflationRateb() == null
                            || stuData.getInflationRateb().compareTo(rightData.getInflationRateb()) != 0) {
                        wrongCount += 1;
                    }
                }
                //通货膨胀率-配偶
                if (rightData.getInflationRatec() != null) {
                    if (stuData.getInflationRatec() == null
                            || stuData.getInflationRatec().compareTo(rightData.getInflationRatec()) != 0) {
                        wrongCount += 1;
                    }
                }
                //收入增长率-客户
                if (rightData.getRevenueGrowthb() != null) {
                    if (stuData.getRevenueGrowthb() == null
                            || stuData.getRevenueGrowthb().compareTo(rightData.getRevenueGrowthb()) != 0) {
                        wrongCount += 1;
                    }
                }
                //收入增长率-配偶
                if (rightData.getRevenueGrowthc() != null) {
                    if (stuData.getRevenueGrowthc() == null
                            || stuData.getRevenueGrowthc().compareTo(rightData.getRevenueGrowthc()) != 0) {
                        wrongCount += 1;
                    }
                }
                //当前的家庭生活费用-客户
                if (rightData.getMatrimonialFeeb() != null) {
                    if (stuData.getMatrimonialFeeb() == null
                            || stuData.getMatrimonialFeeb().compareTo(rightData.getMatrimonialFeeb()) != 0) {
                        wrongCount += 1;
                    }
                }
                //当前的家庭生活费用-配偶
                if (rightData.getMatrimonialFeec() != null) {
                    if (stuData.getMatrimonialFeec() == null
                            || stuData.getMatrimonialFeec().compareTo(rightData.getMatrimonialFeec()) != 0) {
                        wrongCount += 1;
                    }
                }
                //保险事故发生后支出调整率-客户
                if (rightData.getAfterAccidentRateb() != null) {
                    if (stuData.getAfterAccidentRateb() == null
                            || stuData.getAfterAccidentRateb().compareTo(rightData.getAfterAccidentRateb()) != 0) {
                        wrongCount += 1;
                    }
                }
                //保险事故发生后支出调整率-配偶
                if (rightData.getAfterAccidentRatec() != null) {
                    if (stuData.getAfterAccidentRatec() == null
                            || stuData.getAfterAccidentRatec().compareTo(rightData.getAfterAccidentRatec()) != 0) {
                        wrongCount += 1;
                    }
                }
                //配偶的个人年收入-客户
                if (rightData.getIncomeb() != null) {
                    if (stuData.getIncomeb() == null
                            || stuData.getIncomeb().compareTo(rightData.getIncomeb()) != 0) {
                        wrongCount += 1;
                    }
                }
                //配偶的个人年收入-配偶
                if (rightData.getIncomec() != null) {
                    if (stuData.getIncomec() == null
                            || stuData.getIncomec().compareTo(rightData.getIncomec()) != 0) {
                        wrongCount += 1;
                    }
                }
                //临终及丧葬支出现值-客户
                if (rightData.getDeathExpenseb() != null) {
                    if (stuData.getDeathExpenseb() == null
                            || stuData.getDeathExpenseb().compareTo(rightData.getDeathExpenseb()) != 0) {
                        wrongCount += 1;
                    }
                }
                //临终及丧葬支出现值-配偶
                if (rightData.getDeathExpensec() != null) {
                    if (stuData.getDeathExpensec() == null
                            || stuData.getDeathExpensec().compareTo(rightData.getDeathExpensec()) != 0) {
                        wrongCount += 1;
                    }
                }
                //目前贷款余额-客户
                if (rightData.getLoanBalanceb() != null) {
                    if (stuData.getLoanBalanceb() == null
                            || stuData.getLoanBalanceb().compareTo(rightData.getLoanBalanceb()) != 0) {
                        wrongCount += 1;
                    }
                }
                //目前贷款余额-配偶
                if (rightData.getLoanBalancec() != null) {
                    if (stuData.getLoanBalancec() == null
                            || stuData.getLoanBalancec().compareTo(rightData.getLoanBalancec()) != 0) {
                        wrongCount += 1;
                    }
                }
                //家庭生息资产-客户
                if (rightData.getReserveFundb() != null) {
                    if (stuData.getReserveFundb() == null
                            || stuData.getReserveFundb().compareTo(rightData.getReserveFundb()) != 0) {
                        wrongCount += 1;
                    }
                }
                //家庭生息资产-配偶
                if (rightData.getReserveFundc() != null) {
                    if (stuData.getReserveFundc() == null
                            || stuData.getReserveFundc().compareTo(rightData.getReserveFundc()) != 0) {
                        wrongCount += 1;
                    }
                }
                //已有额度-客户
                if (rightData.getInsuranceAmountb() != null) {
                    if (stuData.getInsuranceAmountb() == null
                            || stuData.getInsuranceAmountb().compareTo(rightData.getInsuranceAmountb()) != 0) {
                        wrongCount += 1;
                    }
                }
                //已有额度-配偶
                if (rightData.getInsuranceAmountc() != null) {
                    if (stuData.getInsuranceAmountc() == null
                            || stuData.getInsuranceAmountc().compareTo(rightData.getInsuranceAmountc()) != 0) {
                        wrongCount += 1;
                    }
                }
                //预算金额-客户
                if (rightData.getBudgetAmountb() != null) {
                    if (stuData.getBudgetAmountb() == null
                            || stuData.getBudgetAmountb().compareTo(rightData.getBudgetAmountb()) != 0) {
                        wrongCount += 1;
                    }
                }
                //预算金额-配偶
                if (rightData.getBudgetAmountc() != null) {
                    if (stuData.getBudgetAmountc() == null
                            || stuData.getBudgetAmountc().compareTo(rightData.getBudgetAmountc()) != 0) {
                        wrongCount += 1;
                    }
                }
                //补充额度-客户
                if (rightData.getSupplementaryQuotab() != null) {
                    if (stuData.getSupplementaryQuotab() == null
                            || stuData.getSupplementaryQuotab().compareTo(rightData.getSupplementaryQuotab()) != 0) {
                        wrongCount += 1;
                    }
                }
                //补充额度-配偶
                if (rightData.getSupplementaryQuotac() != null) {
                    if (stuData.getSupplementaryQuotac() == null
                            || stuData.getSupplementaryQuotac().compareTo(rightData.getSupplementaryQuotac()) != 0) {
                        wrongCount += 1;
                    }
                }
            }

            //字段全部都取客户的
            if (stuData.getMethodTypeId().equals("生命价值法")) {
                //预计退休年龄-客户
                if (rightData.getEduAmountb() != null) {
                    if (stuData.getEduAmountb() == null
                            || stuData.getEduAmountb().compareTo(rightData.getEduAmountb()) != 0) {
                        wrongCount += 1;
                    }
                }
                //投资报酬率-客户
                if (rightData.getReturnOnInvestmentb() != null) {
                    if (stuData.getReturnOnInvestmentb() == null ||
                            stuData.getReturnOnInvestmentb().compareTo(rightData.getReturnOnInvestmentb()) != 0) {
                        wrongCount += 1;
                    }
                }
                //配偶的个人年收入-客户
                if (rightData.getIncomeb() != null) {
                    if (stuData.getIncomeb() == null
                            || stuData.getIncomeb().compareTo(rightData.getIncomeb()) != 0) {
                        wrongCount += 1;
                    }
                }
                //收入增长率-客户
                if (rightData.getRevenueGrowthb() != null) {
                    if (stuData.getRevenueGrowthb() == null
                            || stuData.getRevenueGrowthb().compareTo(rightData.getRevenueGrowthb()) != 0) {
                        wrongCount += 1;
                    }
                }
                //年支出
                if (rightData.getExpenditure() != null) {
                    if (stuData.getExpenditure() == null
                            || stuData.getExpenditure().compareTo(rightData.getExpenditure()) != 0) {
                        wrongCount += 1;
                    }
                }
                //通货膨胀率-客户
                if (rightData.getInflationRateb() != null) {
                    if (stuData.getInflationRateb() == null
                            || stuData.getInflationRateb().compareTo(rightData.getInflationRateb()) != 0) {
                        wrongCount += 1;
                    }
                }
                //已有额度-客户
                if (rightData.getInsuranceAmountb() != null) {
                    if (stuData.getInsuranceAmountb() == null
                            || stuData.getInsuranceAmountb().compareTo(rightData.getInsuranceAmountb()) != 0) {
                        wrongCount += 1;
                    }
                }
                //预算金额-客户
                if (rightData.getBudgetAmountb() != null) {
                    if (stuData.getBudgetAmountb() == null
                            || stuData.getBudgetAmountb().compareTo(rightData.getBudgetAmountb()) != 0) {
                        wrongCount += 1;
                    }
                }
                //补充额度-客户
                if (rightData.getSupplementaryQuotab() != null) {
                    if (stuData.getSupplementaryQuotab() == null
                            || stuData.getSupplementaryQuotab().compareTo(rightData.getSupplementaryQuotab()) != 0) {
                        wrongCount += 1;
                    }
                }
            }
        }
        return wrongCount;
    }

    private int getCaseRetirementPlanWrongCount(int wrongCount, CaseRetirementPlan stuData) {
        CaseRetirementPlanExample example = new CaseRetirementPlanExample();
        example.createCriteria().andCaseidEqualTo(stuData.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseRetirementPlan> caseRetirementPlans = caseRetirementPlanMapper.selectByExampleWithBLOBs(example);
        if (caseRetirementPlans != null && !caseRetirementPlans.isEmpty()) {
            CaseRetirementPlan rightData = caseRetirementPlans.get(0);
            //退休前通货膨胀率
            if (rightData.getBeforeInflationRate() != null) {
                if (stuData.getBeforeInflationRate() == null
                        || stuData.getBeforeInflationRate().compareTo(rightData.getBeforeInflationRate()) != 0) {
                    wrongCount += 1;
                }
            }
            //退休后通货膨胀率
            if (rightData.getAfterInflationRate() != null) {
                if (stuData.getAfterInflationRate() == null
                        || stuData.getAfterInflationRate().compareTo(rightData.getAfterInflationRate()) != 0) {
                    wrongCount += 1;
                }
            }
            //退休后投资收益率
            if (rightData.getRetirementRate() != null) {
                if (stuData.getRetirementRate() == null
                        || stuData.getRetirementRate().compareTo(rightData.getRetirementRate()) != 0) {
                    wrongCount += 1;
                }
            }
            //计划退休年龄
            if (rightData.getRetirementAge() != null) {
                if (stuData.getRetirementAge() == null
                        || !stuData.getRetirementAge().equals(rightData.getRetirementAge())) {
                    wrongCount += 1;
                }
            }
            //希望享有退休生活年限
            if (rightData.getRetirementYears() != null) {
                if (stuData.getRetirementYears() == null
                        || !stuData.getRetirementYears().equals(rightData.getRetirementYears())) {
                    wrongCount += 1;
                }
            }
            //目前生活水平
            if (rightData.getLivingStandardNow() != null) {
                if (stuData.getLivingStandardNow() == null
                        || !stuData.getLivingStandardNow().equals(rightData.getLivingStandardNow())) {
                    wrongCount += 1;
                }
            }
            //生活满意度
            if (rightData.getSatisfaction() != null) {
                if (stuData.getSatisfaction() == null
                        || !stuData.getSatisfaction().equals(rightData.getSatisfaction())) {
                    wrongCount += 1;
                }
            }
            //退休后、退休前生活水平折算比例
            if (rightData.getConvertProportion() != null) {
                if (stuData.getConvertProportion() == null
                        || stuData.getConvertProportion().compareTo(rightData.getConvertProportion()) != 0) {
                    wrongCount += 1;
                }
            }
            //子女传承费用
            if (rightData.getLineageFee() != null) {
                if (stuData.getLineageFee() == null
                        || stuData.getLineageFee().compareTo(rightData.getLineageFee()) != 0) {
                    wrongCount += 1;
                }
            }
            //社会保险
            if (rightData.getSocialInsurance() != null) {
                if (stuData.getSocialInsurance() == null
                        || stuData.getSocialInsurance().compareTo(rightData.getSocialInsurance()) != 0) {
                    wrongCount += 1;
                }
            }
            //商业保险
            if (rightData.getCommercialInsurance() != null) {
                if (stuData.getCommercialInsurance() == null
                        || stuData.getCommercialInsurance().compareTo(rightData.getCommercialInsurance()) != 0) {
                    wrongCount += 1;
                }
            }
            //租金收入
            if (rightData.getRentIncome() != null) {
                if (stuData.getRentIncome() == null
                        || stuData.getRentIncome().compareTo(rightData.getRentIncome()) != 0) {
                    wrongCount += 1;
                }
            }
            //其他收入
            if (rightData.getOtherIncome() != null) {
                if (stuData.getOtherIncome() == null
                        || stuData.getOtherIncome().compareTo(rightData.getOtherIncome()) != 0) {
                    wrongCount += 1;
                }
            }
        }
        return wrongCount;
    }

    private int getCaseStartAnUndertakingPlanWrongCount(int wrongCount, CaseStartAnUndertakingPlan stuData) {
        CaseStartAnUndertakingPlanExample example = new CaseStartAnUndertakingPlanExample();
        example.createCriteria().andCaseidEqualTo(stuData.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseStartAnUndertakingPlan> caseStartAnUndertakingPlans = caseStartAnUndertakingPlanMapper.selectByExampleWithBLOBs(example);
        if (caseStartAnUndertakingPlans != null && !caseStartAnUndertakingPlans.isEmpty()) {
            CaseStartAnUndertakingPlan rightData = caseStartAnUndertakingPlans.get(0);
            //计划创业年龄
            if (rightData.getStartPlanAge() != null) {
                if (stuData.getStartPlanAge() == null
                        || !stuData.getStartPlanAge().equals(rightData.getStartPlanAge())) {
                    wrongCount += 1;
                }
            }
            //创业时一次性投入金额
            if (rightData.getCostInput() != null) {
                if (stuData.getCostInput() == null
                        || stuData.getCostInput().compareTo(rightData.getCostInput()) != 0) {
                    wrongCount += 1;
                }
            }
        }
        return wrongCount;
    }

    private int getCaseLifeEducationPlanWrongCount(int wrongCount, CaseLifeEducationPlan stuData) {
        CaseLifeEducationPlanExample example = new CaseLifeEducationPlanExample();
        example.createCriteria().andCaseidEqualTo(stuData.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseLifeEducationPlan> caseLifeEducationPlans = caseLifeEducationPlanMapper.selectByExampleWithBLOBs(example);
        if (caseLifeEducationPlans != null && !caseLifeEducationPlans.isEmpty()) {
            CaseLifeEducationPlan rightData = caseLifeEducationPlans.get(0);
            //子女年龄
            if (rightData.getChildAge() != null) {
                if (stuData.getChildAge() == null
                        || !stuData.getChildAge().equals(rightData.getChildAge())) {
                    wrongCount += 1;
                }
            }
            //国内学费增长率
            if (rightData.getInlandEduFee() != null) {
                if (stuData.getInlandEduFee() == null
                        || stuData.getInlandEduFee().compareTo(rightData.getInlandEduFee()) != 0) {
                    wrongCount += 1;
                }
            }
            //国外学费增长率
            if (rightData.getForeignEduFee() != null) {
                if (stuData.getForeignEduFee() == null
                        || stuData.getForeignEduFee().compareTo(rightData.getForeignEduFee()) != 0) {
                    wrongCount += 1;
                }
            }
            //A求学年龄
            if (rightData.getaEduAge() != null) {
                if (stuData.getaEduAge() == null
                        || !stuData.getaEduAge().equals(rightData.getaEduAge())) {
                    wrongCount += 1;
                }
            }
            //A求学时间
            if (rightData.getaEduTime() != null) {
                if (stuData.getaEduTime() == null
                        || !stuData.getaEduTime().equals(rightData.getaEduTime())) {
                    wrongCount += 1;
                }
            }
            //A目前学费
            if (rightData.getaTuition() != null) {
                if (stuData.getaTuition() == null
                        || stuData.getaTuition().compareTo(rightData.getaTuition()) != 0) {
                    wrongCount += 1;
                }
            }
            //B求学年龄
            if (rightData.getbEduAge() != null) {
                if (stuData.getbEduAge() == null
                        || !stuData.getbEduAge().equals(rightData.getbEduAge())) {
                    wrongCount += 1;
                }
            }
            //B求学时间
            if (rightData.getbEduTime() != null) {
                if (stuData.getbEduTime() == null
                        || !stuData.getbEduTime().equals(rightData.getbEduTime())) {
                    wrongCount += 1;
                }
            }
            //B目前学费
            if (rightData.getbTuition() != null) {
                if (stuData.getbTuition() == null
                        || stuData.getbTuition().compareTo(rightData.getbTuition()) != 0) {
                    wrongCount += 1;
                }
            }
            // C求学年龄
            if (rightData.getcEduAge() != null) {
                if (stuData.getcEduAge() == null
                        || !stuData.getcEduAge().equals(rightData.getcEduAge())) {
                    wrongCount += 1;
                }
            }
            //C求学时间
            if (rightData.getcEduTime() != null) {
                if (stuData.getcEduTime() == null
                        || !stuData.getcEduTime().equals(rightData.getcEduTime())) {
                    wrongCount += 1;
                }
            }
            //C目前学费
            if (rightData.getcTuition() != null) {
                if (stuData.getcTuition() == null
                        || stuData.getcTuition().compareTo(rightData.getcTuition()) != 0) {
                    wrongCount += 1;
                }
            }
            //D求学年龄
            if (rightData.getdEduAge() != null) {
                if (stuData.getdEduAge() == null
                        || !stuData.getdEduAge().equals(rightData.getdEduAge())) {
                    wrongCount += 1;
                }
            }
            //D求学时间
            if (rightData.getdEduTime() != null) {
                if (stuData.getdEduTime() == null
                        || !stuData.getdEduTime().equals(rightData.getdEduTime())) {
                    wrongCount += 1;
                }
            }
            //D目前学费
            if (rightData.getdTuition() != null) {
                if (stuData.getdTuition() == null
                        || stuData.getdTuition().compareTo(rightData.getdTuition()) != 0) {
                    wrongCount += 1;
                }
            }
            //E求学年龄
            if (rightData.geteEduAge() != null) {
                if (stuData.geteEduAge() == null
                        || !stuData.geteEduAge().equals(rightData.geteEduAge())) {
                    wrongCount += 1;
                }
            }
            //E求学时间
            if (rightData.geteEduTime() != null) {
                if (stuData.geteEduTime() == null
                        || !stuData.geteEduTime().equals(rightData.geteEduTime())) {
                    wrongCount += 1;
                }
            }
            //E目前学费
            if (rightData.geteTuition() != null) {
                if (stuData.geteTuition() == null
                        || stuData.geteTuition().compareTo(rightData.geteTuition()) != 0) {
                    wrongCount += 1;
                }
            }
            //F求学年龄
            if (rightData.getfEduAge() != null) {
                if (stuData.getfEduAge() == null
                        || !stuData.getfEduAge().equals(rightData.getfEduAge())) {
                    wrongCount += 1;
                }
            }
            //F求学时间
            if (rightData.getfEduTime() != null) {
                if (stuData.getfEduTime() == null
                        || !stuData.getfEduTime().equals(rightData.getfEduTime())) {
                    wrongCount += 1;
                }
            }
            //F目前学费
            if (rightData.getfTuition() != null) {
                if (stuData.getfTuition() == null
                        || stuData.getfTuition().compareTo(rightData.getfTuition()) != 0) {
                    wrongCount += 1;
                }
            }
            //商业保险
            if (rightData.getInsurance() != null) {
                if (stuData.getInsurance() == null
                        || stuData.getInsurance().compareTo(rightData.getInsurance()) != 0) {
                    wrongCount += 1;
                }
            }
            //储蓄计划
            if (rightData.getDeposit() != null) {
                if (stuData.getDeposit() == null
                        || stuData.getDeposit().compareTo(rightData.getDeposit()) != 0) {
                    wrongCount += 1;
                }
            }
            //其他安排
            if (rightData.getOther() != null) {
                if (stuData.getOther() == null
                        || stuData.getOther().compareTo(rightData.getOther()) != 0) {
                    wrongCount += 1;
                }
            }
        }
        return wrongCount;
    }

    private int getCaseCashPlanWrongCount(int wrongCount, CaseCashPlan stuData) {
        CaseCashPlanExample example = new CaseCashPlanExample();
        example.createCriteria().andCaseidEqualTo(stuData.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseCashPlan> caseCashPlans = caseCashPlanMapper.selectByExampleWithBLOBs(example);
        if (caseCashPlans != null && !caseCashPlans.isEmpty()) {
            CaseCashPlan rightData = caseCashPlans.get(0);
            //家庭月支出
            if (rightData.getFamilyMonthExpense() != null) {
                if (stuData.getFamilyMonthExpense() == null || stuData.getFamilyMonthExpense().compareTo(rightData.getFamilyMonthExpense()) != 0) {
                    wrongCount += 1;
                }
            }
        }
        return wrongCount;
    }

    private int getCaseCashFlowWrongCount(int wrongCount, CaseCashFlow stuData) {
        CaseCashFlowExample example = new CaseCashFlowExample();
        example.createCriteria().andCaseidEqualTo(stuData.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseCashFlow> caseCashFlows = caseCashFlowMapper.selectByExample(example);
        if (caseCashFlows != null && !caseCashFlows.isEmpty()) {
            CaseCashFlow rightData = caseCashFlows.get(0);
            //投资赎回
            if (rightData.getRedemption() != null) {
                if (stuData.getRedemption() == null
                        || stuData.getRedemption().compareTo(rightData.getRedemption()) != 0) {
                    wrongCount += 1;
                }
            }
            //新增投资
            if (rightData.getInvestment() != null) {
                if (stuData.getInvestment() == null
                        || stuData.getInvestment().compareTo(rightData.getInvestment()) != 0) {
                    wrongCount += 1;
                }
            }
            //借入本金
            if (rightData.getBorrowCapital() != null) {
                if (stuData.getBorrowCapital() == null
                        || stuData.getBorrowCapital().compareTo(rightData.getBorrowCapital()) != 0) {
                    wrongCount += 1;
                }
            }
            //还款本金
            if (rightData.getRepaymentCapital() != null) {
                if (stuData.getRepaymentCapital() == null
                        || stuData.getRepaymentCapital().compareTo(rightData.getRepaymentCapital()) != 0) {
                    wrongCount += 1;
                }
            }
        }
        return wrongCount;
    }

    private int getCaseIncomeAndExpensesWrongCount(int wrongCount, CaseIncomeAndExpenses stuData) {
        CaseIncomeAndExpensesExample example = new CaseIncomeAndExpensesExample();
        example.createCriteria().andCaseidEqualTo(stuData.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseIncomeAndExpenses> caseIncomeAndExpenses = caseIncomeAndExpensesMapper.selectByExample(example);

        if (caseIncomeAndExpenses != null && !caseIncomeAndExpenses.isEmpty()) {
            CaseIncomeAndExpenses rightData = caseIncomeAndExpenses.get(0);
            //薪资收入
            if (rightData.getJobIncome() != null) {
                if (stuData.getJobIncome() == null
                        || stuData.getJobIncome().compareTo(rightData.getJobIncome()) != 0) {
                    wrongCount += 1;
                }
            }
            //养老保险储蓄
            if (rightData.getEndowmentInsurance() != null) {
                if (stuData.getEndowmentInsurance() == null
                        || stuData.getEndowmentInsurance().compareTo(rightData.getEndowmentInsurance()) != 0) {
                    wrongCount += 1;
                }
            }
            //医疗保险储蓄
            if (rightData.getMedicalInsurance() != null) {
                if (stuData.getMedicalInsurance() == null
                        || stuData.getMedicalInsurance().compareTo(rightData.getMedicalInsurance()) != 0) {
                    wrongCount += 1;
                }
            }
            //住房公积金储蓄
            if (rightData.getHousingFund() != null) {
                if (stuData.getHousingFund() == null
                        || stuData.getHousingFund().compareTo(rightData.getHousingFund()) != 0) {
                    wrongCount += 1;
                }
            }
            //其他工作收入
            if (rightData.getOtherJobIncome() != null) {
                if (stuData.getOtherJobIncome() == null
                        || stuData.getOtherJobIncome().compareTo(rightData.getOtherJobIncome()) != 0) {
                    wrongCount += 1;
                }
            }
            //家计支出
            if (rightData.getFamilyExpense() != null) {
                if (stuData.getFamilyExpense() == null
                        || stuData.getFamilyExpense().compareTo(rightData.getFamilyExpense()) != 0) {
                    wrongCount += 1;
                }
            }
            //子女教育支出
            if (rightData.getChildExpense() != null) {
                if (stuData.getChildExpense() == null
                        || stuData.getChildExpense().compareTo(rightData.getChildExpense()) != 0) {
                    wrongCount += 1;
                }
            }
            //其他支出
            if (rightData.getOtherExpense() != null) {
                if (stuData.getOtherExpense() == null
                        || stuData.getOtherExpense().compareTo(rightData.getOtherExpense()) != 0) {
                    wrongCount += 1;
                }
            }
            //利息收入
            if (rightData.getInterest() != null) {
                if (stuData.getInterest() == null
                        || stuData.getInterest().compareTo(rightData.getInterest()) != 0) {
                    wrongCount += 1;
                }
            }
            //资本利得
            if (rightData.getCapitalGains() != null) {
                if (stuData.getCapitalGains() == null
                        || stuData.getCapitalGains().compareTo(rightData.getCapitalGains()) != 0) {
                    wrongCount += 1;
                }
            }
            //其他理财收入
            if (rightData.getOtherIncome() != null) {
                if (stuData.getOtherIncome() == null
                        || stuData.getOtherIncome().compareTo(rightData.getOtherIncome()) != 0) {
                    wrongCount += 1;
                }
            }
            //利息支出
            if (rightData.getInterestExpense() != null) {
                if (stuData.getInterestExpense() == null
                        || stuData.getInterestExpense().compareTo(rightData.getInterestExpense()) != 0) {
                    wrongCount += 1;
                }
            }
            //保障型保费支出
            if (rightData.getInsuranceExpense() != null) {
                if (stuData.getInsuranceExpense() == null
                        || stuData.getInsuranceExpense().compareTo(rightData.getInsuranceExpense()) != 0) {
                    wrongCount += 1;
                }
            }
            //其他理财支出
            if (rightData.getOtherFinanceExpense() != null) {
                if (stuData.getOtherFinanceExpense() == null
                        || stuData.getOtherFinanceExpense().compareTo(rightData.getOtherFinanceExpense()) != 0) {
                    wrongCount += 1;
                }
            }
        }
        return wrongCount;
    }

    private int getCaseFinanceLiabilityWrongCount(int wrongCount, CaseFinanceLiability stuData) {
        CaseFinanceLiabilityExample example = new CaseFinanceLiabilityExample();
        example.createCriteria().andCaseIdEqualTo(stuData.getCaseId()).andIsAnswerEqualTo("题目答案");
        List<CaseFinanceLiability> caseFinanceLiabilities = caseFinanceLiabilityMapper.selectByExample(example);

        if (caseFinanceLiabilities != null && !caseFinanceLiabilities.isEmpty()) {
            CaseFinanceLiability rightData = caseFinanceLiabilities.get(0);
            //现金
            if (rightData.getCash() != null) {
                if (stuData.getCash() == null
                        || rightData.getCash().compareTo(stuData.getCash()) != 0) {
                    wrongCount += 1;
                }
            }
            //人民币银行活存
            if (rightData.getRmbDeposit() != null) {
                if (stuData.getRmbDeposit() == null
                        || rightData.getRmbDeposit().compareTo(stuData.getRmbDeposit()) != 0) {
                    wrongCount += 1;
                }
            }
            //其他流动资产
            if (rightData.getOtherAsset() != null) {
                if (stuData.getOtherAsset() == null
                        || rightData.getOtherAsset().compareTo(stuData.getOtherAsset()) != 0) {
                    wrongCount += 1;
                }
            }
            //人民币银行定存
            if (rightData.getRmbFixedDeposit() != null) {
                if (stuData.getRmbFixedDeposit() == null
                        || rightData.getRmbFixedDeposit().compareTo(stuData.getRmbFixedDeposit()) != 0) {
                    wrongCount += 1;
                }
            }
            //外币银行定存
            if (rightData.getForeignCurrencyFixedDeposit() != null) {
                if (stuData.getForeignCurrencyFixedDeposit() == null
                        || rightData.getForeignCurrencyFixedDeposit().compareTo(stuData.getForeignCurrencyFixedDeposit()) != 0) {
                    wrongCount += 1;
                }
            }
            //股票投资
            if (rightData.getStockInvestment() != null) {
                if (stuData.getStockInvestment() == null
                        || rightData.getStockInvestment().compareTo(stuData.getStockInvestment()) != 0) {
                    wrongCount += 1;
                }
            }
            //债券投资
            if (rightData.getBondInvestment() != null) {
                if (stuData.getBondInvestment() == null
                        || rightData.getBondInvestment().compareTo(stuData.getBondInvestment()) != 0) {
                    wrongCount += 1;
                }
            }
            //基金投资
            if (rightData.getFundInvestment() != null) {
                if (stuData.getFundInvestment() == null
                        || rightData.getFundInvestment().compareTo(stuData.getFundInvestment()) != 0) {
                    wrongCount += 1;
                }
            }
            //实业投资
            if (rightData.getIndustryInvestment() != null) {
                if (stuData.getIndustryInvestment() == null
                        || rightData.getIndustryInvestment().compareTo(stuData.getIndustryInvestment()) != 0) {
                    wrongCount += 1;
                }
            }
            //投资性房地产
            if (rightData.getEstateInvestment() != null) {
                if (stuData.getEstateInvestment() == null
                        || rightData.getEstateInvestment().compareTo(stuData.getEstateInvestment()) != 0) {
                    wrongCount += 1;
                }
            }
            //保单现金价值
            if (rightData.getPolicyInvestment() != null) {
                if (stuData.getPolicyInvestment() == null
                        || rightData.getPolicyInvestment().compareTo(stuData.getPolicyInvestment()) != 0) {
                    wrongCount += 1;
                }
            }
            //其他投资性资产
            if (rightData.getOtherInvestment() != null) {
                if (stuData.getOtherInvestment() == null
                        || rightData.getOtherInvestment().compareTo(stuData.getOtherInvestment()) != 0) {
                    wrongCount += 1;
                }
            }
            //自用房地产
            if (rightData.getEstate() != null) {
                if (stuData.getEstate() == null || rightData.getEstate().compareTo(stuData.getEstate()) != 0) {
                    wrongCount += 1;
                }
            }
            //自用汽车
            if (rightData.getCar() != null) {
                if (stuData.getCar() == null || rightData.getCar().compareTo(stuData.getCar()) != 0) {
                    wrongCount += 1;
                }
            }
            //自用其他资产
            if (rightData.getOthers() != null) {
                if (stuData.getOthers() == null || rightData.getOthers().compareTo(stuData.getOthers()) != 0) {
                    wrongCount += 1;
                }
            }
            //信用卡欠款
            if (rightData.getCreditCard() != null) {
                if (stuData.getCreditCard() == null || rightData.getCreditCard().compareTo(stuData.getCreditCard()) != 0) {
                    wrongCount += 1;
                }
            }
            //小额消费信贷
            if (rightData.getMicrofinance() != null) {
                if (stuData.getMicrofinance() == null || rightData.getMicrofinance().compareTo(stuData.getMicrofinance()) != 0) {
                    wrongCount += 1;
                }
            }
            //其他消费性负债
            if (rightData.getOtherLoan() != null) {
                if (stuData.getOtherLoan() == null || rightData.getOtherLoan().compareTo(stuData.getOtherLoan()) != 0) {
                    wrongCount += 1;
                }
            }
            //金融投资借款
            if (rightData.getFinancialLoan() != null) {
                if (stuData.getFinancialLoan() == null || rightData.getFinancialLoan().compareTo(stuData.getFinancialLoan()) != 0) {
                    wrongCount += 1;
                }
            }
            //实业投资借款
            if (rightData.getIndustryInvestmentLoan() != null) {
                if (stuData.getIndustryInvestmentLoan() == null || rightData.getIndustryInvestmentLoan().compareTo(stuData.getIndustryInvestmentLoan()) != 0) {
                    wrongCount += 1;
                }
            }
            //投资性房地产按揭贷款
            if (rightData.getEstateInvestmentLoan() != null) {
                if (stuData.getEstateInvestmentLoan() == null || rightData.getEstateInvestmentLoan().compareTo(stuData.getEstateInvestmentLoan()) != 0) {
                    wrongCount += 1;
                }
            }
            //其他投资性负债
            if (rightData.getOtherInvestmentLoan() != null) {
                if (stuData.getOtherInvestmentLoan() == null || rightData.getOtherInvestmentLoan().compareTo(stuData.getOtherInvestmentLoan()) != 0) {
                    wrongCount += 1;
                }
            }
            //自用房地产贷款
            if (rightData.getEstateLoan() != null) {
                if (stuData.getEstateLoan() == null || rightData.getEstateLoan().compareTo(stuData.getEstateLoan()) != 0) {
                    wrongCount += 1;
                }
            }
            //自用汽车贷款
            if (rightData.getCarLoan() != null) {
                if (stuData.getCarLoan() == null || rightData.getCarLoan().compareTo(stuData.getCarLoan()) != 0) {
                    wrongCount += 1;
                }
            }
            //其他自用贷款
            if (rightData.getOthersLoan() != null) {
                if (stuData.getOthersLoan() == null || rightData.getOthersLoan().compareTo(stuData.getOthersLoan()) != 0) {
                    wrongCount += 1;
                }
            }
        }
        return wrongCount;
    }

    private int getRiskIndexWrongCount(int wrongCount, CaseRiskIndex stuRiskIndex) {
        //查出正确答案
        CaseRiskIndexExample caseRiskIndexExample = new CaseRiskIndexExample();
        caseRiskIndexExample.createCriteria().andCaseidEqualTo(stuRiskIndex.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseRiskIndex> caseRiskIndices = caseRiskIndexMapper.selectByExample(caseRiskIndexExample);

        if (caseRiskIndices != null && !caseRiskIndices.isEmpty()) {
            CaseRiskIndex rightRiskIndex = caseRiskIndices.get(0);
            //年龄
            if (rightRiskIndex.getAgeScore() != null) {
                if (stuRiskIndex.getAgeScore() == null || rightRiskIndex.getAgeScore().compareTo(stuRiskIndex.getAgeScore()) != 0) {
                    wrongCount += 1;
                }
            }
            //就业状况
            if (rightRiskIndex.getJobScore() != null) {
                if (stuRiskIndex.getJobScore() == null || rightRiskIndex.getJobScore().compareTo(stuRiskIndex.getJobScore()) != 0) {
                    wrongCount += 1;
                }
            }
            //家庭负担
            if (rightRiskIndex.getFamilyScore() != null) {
                if (stuRiskIndex.getFamilyScore() == null || rightRiskIndex.getFamilyScore().compareTo(stuRiskIndex.getFamilyScore()) != 0) {
                    wrongCount += 1;
                }
            }
            //置产状况
            if (rightRiskIndex.getHouseScore() != null) {
                if (stuRiskIndex.getHouseScore() == null || rightRiskIndex.getHouseScore().compareTo(stuRiskIndex.getHouseScore()) != 0) {
                    wrongCount += 1;
                }
            }
            //投资经验
            if (rightRiskIndex.getExpScore() != null) {
                if (stuRiskIndex.getExpScore() == null || rightRiskIndex.getExpScore().compareTo(stuRiskIndex.getExpScore()) != 0) {
                    wrongCount += 1;
                }
            }
            //投资知识
            if (rightRiskIndex.getKnowledgeScore() != null) {
                if (stuRiskIndex.getKnowledgeScore() == null || rightRiskIndex.getKnowledgeScore().compareTo(stuRiskIndex.getKnowledgeScore()) != 0) {
                    wrongCount += 1;
                }
            }
            //忍受亏损百分比
            if (rightRiskIndex.getTolerateScore() != null) {
                if (stuRiskIndex.getTolerateScore() == null || rightRiskIndex.getTolerateScore().compareTo(stuRiskIndex.getTolerateScore()) != 0) {
                    wrongCount += 1;
                }
            }
            //首要考虑
            if (rightRiskIndex.getConsiderationScore() != null) {
                if (stuRiskIndex.getConsiderationScore() == null || rightRiskIndex.getConsiderationScore().compareTo(stuRiskIndex.getConsiderationScore()) != 0) {
                    wrongCount += 1;
                }
            }
            //认赔动作
            if (rightRiskIndex.getLossScore() != null) {
                if (stuRiskIndex.getLossScore() == null || rightRiskIndex.getLossScore().compareTo(stuRiskIndex.getLossScore()) != 0) {
                    wrongCount += 1;
                }
            }
            //赔钱心理
            if (rightRiskIndex.getMentalityScore() != null) {
                if (stuRiskIndex.getMentalityScore() == null || rightRiskIndex.getMentalityScore().compareTo(stuRiskIndex.getMentalityScore()) != 0) {
                    wrongCount += 1;
                }
            }
            //最重要特性
            if (rightRiskIndex.getCharacterScore() != null) {
                if (stuRiskIndex.getCharacterScore() == null || rightRiskIndex.getCharacterScore().compareTo(stuRiskIndex.getCharacterScore()) != 0) {
                    wrongCount += 1;
                }
            }
            //避免工具
            if (rightRiskIndex.getAvoidScore() != null) {
                if (stuRiskIndex.getAvoidScore() == null || rightRiskIndex.getAvoidScore().compareTo(stuRiskIndex.getAvoidScore()) != 0) {
                    wrongCount += 1;
                }
            }
        }
        return wrongCount;
    }

    /**
     * 单个类型查询
     *
     * @param caseID
     * @param type
     * @return
     */
    @Override
    public ResultEntity<Object> getExamPoint(String caseID, String userId, String isAnswer, String type) {
        //报告展示 多个
        if (type.equals("报告")) {
            HashMap<String, Object> map = new HashMap<>();

            if (StringUtils.isNotBlank(userId)) {
                SynthesisPlanClientExample synthesisPlanClientExample = new SynthesisPlanClientExample();
                synthesisPlanClientExample.createCriteria().andUseridEqualTo(userId).andCaseidEqualTo(caseID);
                List<SynthesisPlanClient> synthesisPlanClientList = synthesisPlanClientMapper.selectByExample(synthesisPlanClientExample);
                if (!synthesisPlanClientList.isEmpty()) {
                    SynthesisPlanClient synthesisPlanClient = synthesisPlanClientList.get(0);
                    if (StringUtils.isBlank(synthesisPlanClient.getSubmitStatus())) {
                        synthesisPlanClient.setSubmitStatus("未提交");
                        synthesisPlanClientMapper.updateByPrimaryKey(synthesisPlanClient);
                    }
                }
            }

            ComCaseExample example = new ComCaseExample();
            example.createCriteria().andCaseidEqualTo(caseID);
            List<ComCase> comCases = comCaseMapper.selectByExample(example);

//            SynthesisPlanClientExample example1 = new SynthesisPlanClientExample();
//            example1.createCriteria().andUseridEqualTo(userId).andCaseidEqualTo(caseID);
//            List<SynthesisPlanClient> synthesisPlanClientList = synthesisPlanClientMapper.selectByExample(example1);
//            if (synthesisPlanClientList != null && !synthesisPlanClientList.isEmpty()) {
//                SynthesisPlanClient synthesisPlanClient = synthesisPlanClientList.get(0);
//                synthesisPlanClient.setSubmitStatus("未审核");
//                synthesisPlanClientMapper.updateByPrimaryKey(synthesisPlanClient);
//            }
            if (comCases == null || comCases.isEmpty()) {
                log.info("未查询到综合案例信息表");
                return new ResultEntity<>(HttpStatus.INTERNAL_SERVER_ERROR, "服务器异常，请联系管理员！");
            }

            ComCase comCase = comCases.get(0);
            String[] typeList = comCase.getManageMoneyMattersType().split(",");
            for (String allType : typeList) {
                if (allType.equals("风险测评-风险指标")) {
                    CaseRiskIndex caseRiskIndices = getCaseRiskIndices(caseID, userId, isAnswer);
                    map.put(allType, caseRiskIndices);
                }
                if (allType.equals("财务分析-资产负债表")) {
                    CaseFinanceLiability caseFinanceLiabilities = getCaseFinanceLiabilities(caseID, userId, isAnswer);
                    map.put(allType, caseFinanceLiabilities);
                }
                if (allType.equals("财务分析-收支储蓄表")) {
                    CaseIncomeAndExpenses caseIncomeAndExpenses = getCaseIncomeAndExpenses(caseID, userId, isAnswer);
                    map.put(allType, caseIncomeAndExpenses);
                }
                if (allType.equals("财务分析-现金流量表")) {
                    CaseCashFlow caseCashFlows = getCaseCashFlows(caseID, userId, isAnswer);
                    map.put(allType, caseCashFlows);
                }
                if (allType.equals("财务分析-财务比例分析")) {
                    CaseFinancialRatiosWithBLOBs caseFinancialRatiosWithBLOBs = getCaseFinancialRatiosWithBLOBs(caseID, userId, isAnswer);
                    map.put(allType, caseFinancialRatiosWithBLOBs);
                }
                if (allType.equals("现金规划")) {
                    CaseCashPlan caseCashPlans = getCaseCashPlans(caseID, userId, isAnswer);
                    map.put(allType, caseCashPlans);
                }
                if (allType.equals("生涯规划-教育规划")) {
                    CaseLifeEducationPlan caseLifeEducationPlans = getCaseLifeEducationPlans(caseID, userId, isAnswer);
                    map.put(allType, caseLifeEducationPlans);
                }
                if (allType.equals("生涯规划-消费规划")) {
                    CaseConsumptionPlan CaseConsumptionPlans = getCaseConsumptionPlans(caseID, userId, isAnswer);
                    map.put(allType, CaseConsumptionPlans);
                }
                if (allType.equals("生涯规划-创业规划")) {
                    CaseStartAnUndertakingPlan caseStartAnUndertakingPlans = getCaseStartAnUndertakingPlans(caseID, userId, isAnswer);
                    map.put(allType, caseStartAnUndertakingPlans);
                }
                if (allType.equals("生涯规划-退休规划")) {
                    CaseRetirementPlan caseRetirementPlans = getCaseRetirementPlans(caseID, userId, isAnswer);
                    map.put(allType, caseRetirementPlans);
                }
                if (allType.equals("生涯规划-保险规划")) {
                    CaseInsurancePlan caseInsurancePlans = getCaseInsurancePlans(caseID, userId, isAnswer);
                    map.put(allType, caseInsurancePlans);
                }
                if (allType.equals("投资规划")) {
                    CaseInvestmentPlanDto caseInvestmentPlanDto = getCaseInvestmentPlanDto(caseID, userId, isAnswer);
                    map.put(allType, caseInvestmentPlanDto);
                }
                if (allType.equals("税务筹划")) {
                    CaseTaxPlan caseTaxPlans = getCaseTaxPlans(caseID, userId, isAnswer);
                    map.put(allType, caseTaxPlans);
                }
                if (allType.equals("财产分配")) {
                    CaseDistributionOfPropertyFamilyDto objectResultEntity = getObjectResultEntity(caseID, userId, isAnswer);
                    map.put(allType, objectResultEntity);
                }
                if (allType.equals("财产传承")) {
                    CaseHeritageWithBLOBs resultEntity = getResultEntity(caseID, userId, isAnswer);
                    map.put(allType, resultEntity);
                }
            }
            return new ResultEntity<>(map);
        }

        //单个查看
        //判断是哪种考核点 增加相关表
        if (type.equals("风险测评-风险指标")) {
            return new ResultEntity<>(getCaseRiskIndices(caseID, userId, isAnswer));
        }
        if (type.equals("财务分析-资产负债表")) {
            return new ResultEntity<>(getCaseFinanceLiabilities(caseID, userId, isAnswer));
        }
        if (type.equals("财务分析-收支储蓄表")) {
            return new ResultEntity<>(getCaseIncomeAndExpenses(caseID, userId, isAnswer));
        }
        if (type.equals("财务分析-现金流量表")) {
            return new ResultEntity<>(getCaseCashFlows(caseID, userId, isAnswer));
        }
        if (type.equals("财务分析-财务比例分析")) {
            return new ResultEntity<>(getCaseFinancialRatiosWithBLOBs(caseID, userId, isAnswer));
        }
        if (type.equals("现金规划")) {
            return new ResultEntity<>(getCaseCashPlans(caseID, userId, isAnswer));
        }
        if (type.equals("生涯规划-教育规划")) {
            return new ResultEntity<>(getCaseLifeEducationPlans(caseID, userId, isAnswer));
        }
        if (type.equals("生涯规划-消费规划")) {
            return new ResultEntity<>(getCaseConsumptionPlans(caseID, userId, isAnswer));
        }
        if (type.equals("生涯规划-创业规划")) {
            return new ResultEntity<>(getCaseStartAnUndertakingPlans(caseID, userId, isAnswer));
        }
        if (type.equals("生涯规划-退休规划")) {
            return new ResultEntity<>(getCaseRetirementPlans(caseID, userId, isAnswer));
        }
        if (type.equals("生涯规划-保险规划")) {
            return new ResultEntity<>(getCaseInsurancePlans(caseID, userId, isAnswer));
        }
        if (type.equals("投资规划")) {
            return new ResultEntity<>(getCaseInvestmentPlanDto(caseID, userId, isAnswer));
        }
        if (type.equals("税务筹划")) {
            return new ResultEntity<>(getCaseTaxPlans(caseID, userId, isAnswer));
        }
        if (type.equals("财产分配")) {
            return new ResultEntity<>(getObjectResultEntity(caseID, userId, isAnswer));
        }
        if (type.equals("财产传承")) {
            return new ResultEntity<>(getResultEntity(caseID, userId, isAnswer));
        }
        return null;
    }

    private CaseInvestmentPlanDto getCaseInvestmentPlanDto(String caseID, String userId, String isAnswer) {
        //根据userid查出主对象
        CaseInvestmentPlanExample example = new CaseInvestmentPlanExample();
        CaseInvestmentPlanExample.Criteria criteria = example.createCriteria().andCaseIdEqualTo(caseID).andIsAnswerEqualTo(isAnswer);
        if (StringUtils.isNotBlank(userId)) {
            criteria.andUserIdEqualTo(userId);
        } else {
            criteria.andUserIdIsNull();
        }
        List<CaseInvestmentPlan> caseInvestmentPlans = investmentPlanMapper.selectByExampleWithBLOBs(example);
        if (caseInvestmentPlans.isEmpty()) {
            return null;
        }

        CaseInvestmentPlanDto dto = new CaseInvestmentPlanDto();//返回主对象 包含 CaseInvestmentPlan List<CaseInvestmentPlanSelectDto>
        List<CaseInvestmentPlanSelectDto> caseInvestmentPlanSelectDtos = new ArrayList<>(); //包含CaseInvestmentPlanSelect 和其余五张表的list

        CaseInvestmentPlan caseInvestmentPlan = caseInvestmentPlans.get(0);
        dto.setInvestmentPlan(caseInvestmentPlan);

        //老师或管理员 直接返回
        if (StringUtils.isBlank(userId) && isAnswer.equals("题目答案")) {
            return dto;
        }

        String caseInvestmentPlanId = caseInvestmentPlan.getCaseInvestmentPlanId();
        CaseInvestmentPlanSelectExample investmentPlanSelectExample = new CaseInvestmentPlanSelectExample();
        investmentPlanSelectExample.createCriteria().andCaseInvestmentPlanIdEqualTo(caseInvestmentPlanId);
        List<CaseInvestmentPlanSelect> investmentPlanSelects = caseInvestmentPlanSelectMapper.selectByExampleWithBLOBs(investmentPlanSelectExample);

        if (investmentPlanSelects != null && !investmentPlanSelects.isEmpty()) {
            for (CaseInvestmentPlanSelect investmentPlanSelect : investmentPlanSelects) {
                CaseInvestmentPlanSelectDto caseInvestmentPlanSelectDto = new CaseInvestmentPlanSelectDto();
                caseInvestmentPlanSelectDto.setCaseInvestmentPlanSelect(investmentPlanSelect);
                String productSelectId = investmentPlanSelect.getProductSelectId();

                //set剩余五张表
                //投资规划-银行储蓄信息表
                CaseInvestmentPlanBankProductInfoExample investmentPlanBankProductInfoExample = new CaseInvestmentPlanBankProductInfoExample();
                investmentPlanBankProductInfoExample.createCriteria().andProductSelectIdEqualTo(productSelectId);
                List<CaseInvestmentPlanBankProductInfo> caseInvestmentPlanBankProductInfos = investmentPlanBankProductInfoMapper.selectByExample(investmentPlanBankProductInfoExample);
                caseInvestmentPlanSelectDto.setInvestmentPlanBankProductInfos(caseInvestmentPlanBankProductInfos);

                //投资规划-基金产品信息表
                CaseInvestmentPlanFundProductInfoExample investmentPlanFundProductInfoExample = new CaseInvestmentPlanFundProductInfoExample();
                investmentPlanFundProductInfoExample.createCriteria().andProductSelectIdEqualTo(productSelectId);
                List<CaseInvestmentPlanFundProductInfo> caseInvestmentPlanFundProductInfos = investmentPlanFundProductInfoMapper.selectByExample(investmentPlanFundProductInfoExample);
                caseInvestmentPlanSelectDto.setInvestmentPlanFundProductInfos(caseInvestmentPlanFundProductInfos);

                //投资规划-保险产品信息表
                CaseInvestmentPlanInsuranceProductInfoExample investmentPlanInsuranceProductInfoExample = new CaseInvestmentPlanInsuranceProductInfoExample();
                investmentPlanInsuranceProductInfoExample.createCriteria().andProductSelectIdEqualTo(productSelectId);
                List<CaseInvestmentPlanInsuranceProductInfo> caseInvestmentPlanInsuranceProductInfos = investmentPlanInsuranceProductInfoMapper.selectByExample(investmentPlanInsuranceProductInfoExample);
                caseInvestmentPlanSelectDto.setInvestmentPlanInsuranceProductInfos(caseInvestmentPlanInsuranceProductInfos);

                //投资规划-P2P产品信息表
                CaseInvestmentPlanP2PProductInfoExample caseInvestmentPlanP2PProductInfoExample = new CaseInvestmentPlanP2PProductInfoExample();
                caseInvestmentPlanP2PProductInfoExample.createCriteria().andProductSelectIdEqualTo(productSelectId);
                List<CaseInvestmentPlanP2PProductInfo> caseInvestmentPlanP2PProductInfos = investmentPlanP2PProductInfoMapper.selectByExample(caseInvestmentPlanP2PProductInfoExample);
                caseInvestmentPlanSelectDto.setInvestmentPlanP2PProductInfos(caseInvestmentPlanP2PProductInfos);

                //投资规划-实物黄金信息表
                CaseInvestmentPlanRealGoldProductInfoExample caseInvestmentPlanRealGoldProductInfoExample = new CaseInvestmentPlanRealGoldProductInfoExample();
                caseInvestmentPlanRealGoldProductInfoExample.createCriteria().andProductSelectIdEqualTo(productSelectId);
                List<CaseInvestmentPlanRealGoldProductInfo> caseInvestmentPlanRealGoldProductInfos = investmentPlanRealGoldProductInfoMapper.selectByExample(caseInvestmentPlanRealGoldProductInfoExample);
                caseInvestmentPlanSelectDto.setInvestmentPlanRealGoldProductInfos(caseInvestmentPlanRealGoldProductInfos);

                caseInvestmentPlanSelectDtos.add(caseInvestmentPlanSelectDto);
            }
        }
        dto.setCaseInvestmentPlanSelectDtos(caseInvestmentPlanSelectDtos);
        return dto;
    }

    private CaseHeritageWithBLOBs getResultEntity(String caseID, String userId, String isAnswer) {
        CaseHeritageExample example = new CaseHeritageExample();
        CaseHeritageExample.Criteria criteria = example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer);
        if (StringUtils.isBlank(userId)) {
            criteria.andUserIdIsNull();
        } else {
            criteria.andUserIdEqualTo(userId);
        }
        List<CaseHeritageWithBLOBs> caseHeritageWithBLOBs = caseHeritageMapper.selectByExampleWithBLOBs(example);
        if (caseHeritageWithBLOBs == null || caseHeritageWithBLOBs.isEmpty()) {
            return null;
        }
        return caseHeritageWithBLOBs.get(0);
    }

    private CaseDistributionOfPropertyFamilyDto getObjectResultEntity(String caseID, String userId, String
            isAnswer) {
        CaseDistributionOfPropertyExample example = new CaseDistributionOfPropertyExample();
        CaseDistributionOfPropertyExample.Criteria criteria = example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer);
        if (StringUtils.isBlank(userId)) {
            criteria.andUserIdIsNull();
        } else {
            criteria.andUserIdEqualTo(userId);
        }
        List<CaseDistributionOfPropertyWithBLOBs> caseDistributionOfPropertyWithBLOBs = caseDistributionOfPropertyMapper.selectByExampleWithBLOBs(example);
        if (caseDistributionOfPropertyWithBLOBs == null || caseDistributionOfPropertyWithBLOBs.isEmpty()) {
            return null;
        }
        CaseDistributionOfPropertyWithBLOBs caseDistributionOfPropertyWithBLOB = caseDistributionOfPropertyWithBLOBs.get(0);
        CaseDistributionOfPropertyFamilyDto dto = new CaseDistributionOfPropertyFamilyDto();
        BeanUtils.copyProperties(caseDistributionOfPropertyWithBLOB, dto);

        if (isAnswer.equals("题目答案")) {
            return dto;
        }

        CaseDistributionOfPropertyFamilyRecordsExample propertyFamilyRecordsExample = new CaseDistributionOfPropertyFamilyRecordsExample();
        propertyFamilyRecordsExample.createCriteria().andCaseDistributionOfPropertyIdEqualTo(caseDistributionOfPropertyWithBLOB.getCaseDistributionOfPropertyId())
                .andUserIdEqualTo(userId);
        List<CaseDistributionOfPropertyFamilyRecords> recordsList = caseDistributionOfPropertyFamilyRecordsMapper.selectByExample(propertyFamilyRecordsExample);
        dto.setCaseDistributionOfPropertyFamilyRecordsList(recordsList);
        return dto;
    }

    private CaseTaxPlan getCaseTaxPlans(String caseID, String userId, String isAnswer) {
        CaseTaxPlanExample example = new CaseTaxPlanExample();
        CaseTaxPlanExample.Criteria criteria = example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer);
        if (StringUtils.isBlank(userId)) {
            criteria.andUserIdIsNull();
        } else {
            criteria.andUserIdEqualTo(userId);
        }
        List<CaseTaxPlan> caseTaxPlans = caseTaxPlanMapper.selectByExampleWithBLOBs(example);
        if (caseTaxPlans == null || caseTaxPlans.isEmpty()) {
            return null;
        }
        return caseTaxPlans.get(0);
    }

    private CaseInsurancePlan getCaseInsurancePlans(String caseID, String userId, String isAnswer) {
        CaseInsurancePlanExample example = new CaseInsurancePlanExample();
        CaseInsurancePlanExample.Criteria criteria = example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer);
        if (StringUtils.isBlank(userId)) {
            criteria.andUserIdIsNull();
        } else {
            criteria.andUserIdEqualTo(userId);
        }
        List<CaseInsurancePlan> caseInsurancePlans = caseInsurancePlanMapper.selectByExampleWithBLOBs(example);
        if (caseInsurancePlans == null || caseInsurancePlans.isEmpty()) {
            return null;
        }
        return caseInsurancePlans.get(0);
    }

    private CaseRetirementPlan getCaseRetirementPlans(String caseID, String userId, String isAnswer) {
        CaseRetirementPlanExample example = new CaseRetirementPlanExample();
        CaseRetirementPlanExample.Criteria criteria = example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer);
        if (StringUtils.isBlank(userId)) {
            criteria.andUserIdIsNull();
        } else {
            criteria.andUserIdEqualTo(userId);
        }
        List<CaseRetirementPlan> caseRetirementPlans = caseRetirementPlanMapper.selectByExampleWithBLOBs(example);
        if (caseRetirementPlans == null || caseRetirementPlans.isEmpty()) {
            return null;
        }
        return caseRetirementPlans.get(0);
    }

    private CaseStartAnUndertakingPlan getCaseStartAnUndertakingPlans(String caseID, String userId, String
            isAnswer) {
        CaseStartAnUndertakingPlanExample example = new CaseStartAnUndertakingPlanExample();
        CaseStartAnUndertakingPlanExample.Criteria criteria = example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer);
        if (StringUtils.isBlank(userId)) {
            criteria.andUserIdIsNull();
        } else {
            criteria.andUserIdEqualTo(userId);
        }
        List<CaseStartAnUndertakingPlan> caseStartAnUndertakingPlans = caseStartAnUndertakingPlanMapper.selectByExampleWithBLOBs(example);
        if (caseStartAnUndertakingPlans == null || caseStartAnUndertakingPlans.isEmpty()) {
            return null;
        }
        return caseStartAnUndertakingPlans.get(0);
    }

    private CaseConsumptionPlan getCaseConsumptionPlans(String caseID, String userId, String isAnswer) {
        CaseConsumptionPlanExample example = new CaseConsumptionPlanExample();
        CaseConsumptionPlanExample.Criteria criteria = example.createCriteria().andCaseIdEqualTo(caseID).andIsAnswerEqualTo(isAnswer);
        if (StringUtils.isBlank(userId)) {
            criteria.andUserIdIsNull();
        } else {
            criteria.andUserIdEqualTo(userId);
        }
        List<CaseConsumptionPlan> CaseConsumptionPlans = caseConsumptionPlanMapper.selectByExampleWithBLOBs(example);
        if (CaseConsumptionPlans == null || CaseConsumptionPlans.isEmpty()) {
            return null;
        }
        return CaseConsumptionPlans.get(0);
    }

    private CaseLifeEducationPlan getCaseLifeEducationPlans(String caseID, String userId, String isAnswer) {
        CaseLifeEducationPlanExample example = new CaseLifeEducationPlanExample();
        CaseLifeEducationPlanExample.Criteria criteria = example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer);
        if (StringUtils.isBlank(userId)) {
            criteria.andUserIdIsNull();
        } else {
            criteria.andUserIdEqualTo(userId);
        }
        List<CaseLifeEducationPlan> caseLifeEducationPlans = caseLifeEducationPlanMapper.selectByExampleWithBLOBs(example);
        if (caseLifeEducationPlans == null || caseLifeEducationPlans.isEmpty()) {
            return null;
        }
        return caseLifeEducationPlans.get(0);
    }

    private CaseCashPlan getCaseCashPlans(String caseID, String userId, String isAnswer) {
        CaseCashPlanExample example = new CaseCashPlanExample();
        CaseCashPlanExample.Criteria criteria = example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer);
        if (StringUtils.isBlank(userId)) {
            criteria.andUserIdIsNull();
        } else {
            criteria.andUserIdEqualTo(userId);
        }
        List<CaseCashPlan> caseCashPlans = caseCashPlanMapper.selectByExampleWithBLOBs(example);
        if (caseCashPlans == null || caseCashPlans.isEmpty()) {
            return null;
        }
        return caseCashPlans.get(0);
    }

    private CaseFinancialRatiosWithBLOBs getCaseFinancialRatiosWithBLOBs(String caseID, String userId, String
            isAnswer) {
        CaseFinancialRatiosExample example = new CaseFinancialRatiosExample();
        CaseFinancialRatiosExample.Criteria criteria = example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer);
        if (StringUtils.isBlank(userId)) {
            criteria.andUserIdIsNull();
        } else {
            criteria.andUserIdEqualTo(userId);
        }
        List<CaseFinancialRatiosWithBLOBs> caseFinancialRatiosWithBLOBs = caseFinancialRatiosMapper.selectByExampleWithBLOBs(example);
        if (caseFinancialRatiosWithBLOBs == null || caseFinancialRatiosWithBLOBs.isEmpty()) {
            return null;
        }
        return caseFinancialRatiosWithBLOBs.get(0);
    }

    private CaseCashFlow getCaseCashFlows(String caseID, String userId, String isAnswer) {
        CaseCashFlowExample example = new CaseCashFlowExample();
        CaseCashFlowExample.Criteria criteria = example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer);
        if (StringUtils.isBlank(userId)) {
            criteria.andUserIdIsNull();
        } else {
            criteria.andUserIdEqualTo(userId);
        }
        List<CaseCashFlow> caseCashFlows = caseCashFlowMapper.selectByExample(example);
        if (caseCashFlows == null || caseCashFlows.isEmpty()) {
            return null;
        }
        return caseCashFlows.get(0);
    }

    private CaseIncomeAndExpenses getCaseIncomeAndExpenses(String caseID, String userId, String isAnswer) {
        CaseIncomeAndExpensesExample example = new CaseIncomeAndExpensesExample();
        CaseIncomeAndExpensesExample.Criteria criteria = example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer);
        if (StringUtils.isBlank(userId)) {
            criteria.andUserIdIsNull();
        } else {
            criteria.andUserIdEqualTo(userId);
        }
        List<CaseIncomeAndExpenses> caseIncomeAndExpenses = caseIncomeAndExpensesMapper.selectByExample(example);
        if (caseIncomeAndExpenses == null || caseIncomeAndExpenses.isEmpty()) {
            return null;
        }
        return caseIncomeAndExpenses.get(0);
    }

    private CaseFinanceLiability getCaseFinanceLiabilities(String caseID, String userId, String isAnswer) {
        CaseFinanceLiabilityExample example = new CaseFinanceLiabilityExample();
        CaseFinanceLiabilityExample.Criteria criteria = example.createCriteria().andCaseIdEqualTo(caseID).andIsAnswerEqualTo(isAnswer);
        if (StringUtils.isBlank(userId)) {
            criteria.andUserIdIsNull();
        } else {
            criteria.andUserIdEqualTo(userId);
        }
        List<CaseFinanceLiability> caseFinanceLiabilities = caseFinanceLiabilityMapper.selectByExample(example);
        if (caseFinanceLiabilities == null || caseFinanceLiabilities.isEmpty()) {
            return null;
        }
        return caseFinanceLiabilities.get(0);
    }

    private CaseRiskIndex getCaseRiskIndices(String caseID, String userId, String isAnswer) {
        CaseRiskIndexExample example = new CaseRiskIndexExample();
        CaseRiskIndexExample.Criteria criteria = example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer);
        if (StringUtils.isBlank(userId)) {
            criteria.andUseridIsNull();
        } else {
            criteria.andUseridEqualTo(userId);
        }
        List<CaseRiskIndex> caseRiskIndices = caseRiskIndexMapper.selectByExample(example);
        if (caseRiskIndices == null || caseRiskIndices.isEmpty()) {
            return null;
        }
        return caseRiskIndices.get(0);
    }

//
//    /**
//     * 编辑
//     *
//     * @param json
//     * @param type
//     * @return
//     */
//    @Override
//    public ResultEntity<HttpStatus> updateExamPoint(String json, String type) {
//        //判断是哪种考核点 增加相关表
//        try {
//            Gson gson = new Gson();
//            if (StringUtils.isNotBlank(json)) {
//                if (type.equals("风险测评-风险指标")) {
//                    CaseRiskIndex caseRiskIndex = gson.fromJson(json, CaseRiskIndex.class);
//                    caseRiskIndexMapper.updateByPrimaryKeySelective(caseRiskIndex);
//                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
//                }
//
//                if (type.equals("财务分析-资产负债表")) {
//                    CaseFinanceLiability caseFinanceLiability = gson.fromJson(json, CaseFinanceLiability.class);
//                    caseFinanceLiabilityMapper.updateByPrimaryKeySelective(caseFinanceLiability);
//                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
//                }
//
//                if (type.equals("财务分析-收支储蓄表")) {
//                    CaseIncomeAndExpenses caseIncomeAndExpenses = gson.fromJson(json, CaseIncomeAndExpenses.class);
//                    caseIncomeAndExpensesMapper.updateByPrimaryKeySelective(caseIncomeAndExpenses);
//                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
//                }
//
//                if (type.equals("财务分析-现金流量表")) {
//                    CaseCashFlow caseCashFlow = gson.fromJson(json, CaseCashFlow.class);
//                    caseCashFlowMapper.updateByPrimaryKeySelective(caseCashFlow);
//                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
//                }
//
//                if (type.equals("财务分析-财务比例分析")) {
//                    CaseFinancialRatiosWithBLOBs caseFinancialRatios = gson.fromJson(json, CaseFinancialRatiosWithBLOBs.class);
//                    caseFinancialRatiosMapper.updateByPrimaryKeySelective(caseFinancialRatios);
//                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
//                }
//
//                if (type.equals("现金规划")) {
//                    CaseCashPlan caseCashPlan = gson.fromJson(json, CaseCashPlan.class);
//                    caseCashPlanMapper.updateByPrimaryKeySelective(caseCashPlan);
//                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
//                }
//
//                if (type.equals("生涯规划-教育规划")) {
//                    CaseLifeEducationPlan caseLifeEducationPlan = gson.fromJson(json, CaseLifeEducationPlan.class);
//                    caseLifeEducationPlanMapper.updateByPrimaryKeySelective(caseLifeEducationPlan);
//                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
//                }
//
//                if (type.equals("生涯规划-消费规划")) {
//                    //todo 暂无数据库表
//                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
//                }
//
//
//                if (type.equals("生涯规划-创业规划")) {
//                    CaseStartAnUndertakingPlan caseStartAnUndertakingPlan = gson.fromJson(json, CaseStartAnUndertakingPlan.class);
//                    caseStartAnUndertakingPlanMapper.updateByPrimaryKeySelective(caseStartAnUndertakingPlan);
//                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
//                }
//
//                if (type.equals("生涯规划-退休规划")) {
//                    CaseRetirementPlan caseRetirementPlan = gson.fromJson(json, CaseRetirementPlan.class);
//                    caseRetirementPlanMapper.updateByPrimaryKeySelective(caseRetirementPlan);
//                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
//                }
//
//                if (type.equals("生涯规划-保险规划")) {
//                    CaseInsurancePlan caseInsurancePlan = gson.fromJson(json, CaseInsurancePlan.class);
//                    caseInsurancePlanMapper.updateByPrimaryKeySelective(caseInsurancePlan);
//                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
//                }
//
//                if (type.equals("投资规划")) {
//                    // todo 表暂时没有
//                    return null;
//                }
//
//                if (type.equals("税务筹划")) {
//                    CaseTaxPlan caseTaxPlan = gson.fromJson(json, CaseTaxPlan.class);
//                    caseTaxPlanMapper.updateByPrimaryKeySelective(caseTaxPlan);
//                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
//                }
//
//                if (type.equals("财产分配")) {
//                    CaseDistributionOfPropertyWithBLOBs caseDistributionOfPropertyWithBLOBs = gson.fromJson(json, CaseDistributionOfPropertyWithBLOBs.class);
//                    caseDistributionOfPropertyMapper.updateByPrimaryKeySelective(caseDistributionOfPropertyWithBLOBs);
//                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
//                }
//
//                if (type.equals("财产传承")) {
//                    CaseHeritageWithBLOBs caseHeritageWithBLOBs = gson.fromJson(json, CaseHeritageWithBLOBs.class);
//                    caseHeritageMapper.updateByPrimaryKeySelective(caseHeritageWithBLOBs);
//                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
//                }
//            }
//        } catch (Exception e) {
//            return new ResultEntity<HttpStatus>(HttpStatus.INTERNAL_SERVER_ERROR, "服务器异常，请联系管理员！");
//        }
//        return null;
//    }
}