package com.sztzjy.money_management.util;

import com.github.benmanes.caffeine.cache.Cache;
import com.github.benmanes.caffeine.cache.Caffeine;

import java.util.concurrent.TimeUnit;
import java.util.function.Function;

/**
 * 咖啡因提供的缓存工具类
 *  
 */
public class CacheProvider {
    private Cache<String, Object> cache = null;
    public CacheProvider(Integer expire, Integer maxSize) {
        /**
         * 基于时间的移除：expireAfterAccess(long, TimeUnit) 根据某个键值对最后一次访问之后多少时间后移除
         * 　　　　　　　　expireAfterWrite(long, TimeUnit) 根据某个键值对被创建或值被替换后多少时间移除
         */
        if(cache==null){
            cache = Caffeine.newBuilder()
                    .expireAfterWrite(expire, TimeUnit.SECONDS)
                    .maximumSize(maxSize)
                    .build();
        }
    }

    public long getSize(){
        return cache.estimatedSize();
    }

    public void put(String key,String value){
        cache.put(key, value);
    }
    public void put(String key,Object value){
        cache.put(key, value);
    }

    public Object get(String key){
        return cache.getIfPresent(key);
    }

    public Object get(String key,Function<? super String, ? extends Object> fc){
        return cache.get(key,fc);
    }

    public void remove(String key){
        cache.invalidate(key);
    }
}
